All Classes and Interfaces

Class
Description
The operation did not succeed because of an unauthorized access attempt.
 
 
 
An AWS Arn.
Contains details about a package version asset.
 
A package associated with a package group.
 
 
 
 
 
 
Service client for accessing CodeArtifact asynchronously.
A builder for creating an instance of CodeartifactAsyncClient.
 
The parameters object used to resolve the auth schemes for the Codeartifact service.
An auth scheme provider for Codeartifact service.
This includes configuration specific to CodeArtifact that is supported by both CodeartifactClientBuilder and CodeartifactAsyncClientBuilder.
Service client for accessing CodeArtifact.
A builder for creating an instance of CodeartifactClient.
 
The parameters object used to resolve an endpoint for the Codeartifact service.
 
An endpoint provider for Codeartifact.
 
 
 
 
 
 
 
 
 
 
 
 
Class to expose the service client settings to the user.
 
The operation did not succeed because prerequisites are not met.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Information about a domain.
 
Information about how a package originally entered the CodeArtifact domain.
 
 
Information about a domain, including its name, Amazon Resource Name (ARN), and status.
 
Link between an endpoint property and the AwsEndpointAttribute it represents.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Identifiers for variables declared within the rule engine, e.g.
The operation did not succeed because of an error that occurred inside CodeArtifact.
 
Details of the license data.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Details about a package dependency.
 
Details about a package.
 
 
Details about an allowed repository for a package group, including its name and origin configuration.
 
 
 
The description of the package group.
 
The package group origin configuration that determines how package versions can enter repositories.
 
Contains information about the configured restrictions of the origin controls of a package group.
 
 
 
Information about the identifiers of a package group.
 
Details about a package group.
 
Details about the package origin configuration of a package.
 
Details about the origin restrictions set on the package.
 
Details about a package, including its format, namespace, and name.
 
Details about a package version.
 
l An error associated with package.
 
 
Information about how a package version was added to a repository.
 
 
 
 
Details about a package version, including its status, version, and revision.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
The details of a repository stored in CodeArtifact.
 
Contains information about the external connection of a repository.
 
Details about a repository, including its Amazon Resource Name (ARN), description, and domain information.
 
The operation did not succeed because the resource requested is not found in the service.
 
An CodeArtifact resource policy that contains a resource ARN, document details, and a revision.
 
 
 
 
 
 
 
Represents a URL to be used internally for endpoint resolution.
The operation did not succeed because it would have exceeded a service limit for your account.
 
 
Contains the revision and status of a package version.
 
A tag is a key-value pair that can be used to manage, search for, or filter resources in CodeArtifact.
 
 
 
 
 
The operation did not succeed because too many requests are sent to the service.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Information about an upstream repository.
 
Information about an upstream repository.
 
 
The operation did not succeed because a parameter in the request was sent with an invalid value.
 
 
Base class for the types of values computable by the RuleEngine.
An array value.
A boolean value.
 
 
An integer value.
 
A record (map) value.
A string value.