Uses of Interface
software.amazon.awssdk.services.codeartifact.CodeartifactClientBuilder
Packages that use CodeartifactClientBuilder
Package
Description
CodeArtifact is a fully managed artifact repository compatible with language-native package managers and build tools
such as npm, Apache Maven, pip, and dotnet.
-
Uses of CodeartifactClientBuilder in software.amazon.awssdk.services.codeartifact
Methods in software.amazon.awssdk.services.codeartifact that return CodeartifactClientBuilderModifier and TypeMethodDescriptionstatic CodeartifactClientBuilderCodeartifactClient.builder()Create a builder that can be used to configure and create aCodeartifactClient.