Class AssociateExternalConnectionRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<AssociateExternalConnectionRequest.Builder,AssociateExternalConnectionRequest>

@Generated("software.amazon.awssdk:codegen") public final class AssociateExternalConnectionRequest extends CodeartifactRequest implements ToCopyableBuilder<AssociateExternalConnectionRequest.Builder,AssociateExternalConnectionRequest>
  • Method Details

    • domain

      public final String domain()

      The name of the domain that contains the repository.

      Returns:
      The name of the domain that contains the repository.
    • domainOwner

      public final String domainOwner()

      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

      Returns:
      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
    • repository

      public final String repository()

      The name of the repository to which the external connection is added.

      Returns:
      The name of the repository to which the external connection is added.
    • externalConnection

      public final String externalConnection()

      The name of the external connection to add to the repository. The following values are supported:

      • public:npmjs - for the npm public repository.

      • public:nuget-org - for the NuGet Gallery.

      • public:pypi - for the Python Package Index.

      • public:maven-central - for Maven Central.

      • public:maven-googleandroid - for the Google Android repository.

      • public:maven-gradleplugins - for the Gradle plugins repository.

      • public:maven-commonsware - for the CommonsWare Android repository.

      • public:maven-clojars - for the Clojars repository.

      • public:ruby-gems-org - for RubyGems.org.

      • public:crates-io - for Crates.io.

      Returns:
      The name of the external connection to add to the repository. The following values are supported:

      • public:npmjs - for the npm public repository.

      • public:nuget-org - for the NuGet Gallery.

      • public:pypi - for the Python Package Index.

      • public:maven-central - for Maven Central.

      • public:maven-googleandroid - for the Google Android repository.

      • public:maven-gradleplugins - for the Gradle plugins repository.

      • public:maven-commonsware - for the CommonsWare Android repository.

      • public:maven-clojars - for the Clojars repository.

      • public:ruby-gems-org - for RubyGems.org.

      • public:crates-io - for Crates.io.

    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<AssociateExternalConnectionRequest.Builder,AssociateExternalConnectionRequest>
      Specified by:
      toBuilder in class CodeartifactRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends AssociateExternalConnectionRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo