Class AssociateExternalConnectionResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.codeartifact.model.CodeartifactResponse
software.amazon.awssdk.services.codeartifact.model.AssociateExternalConnectionResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<AssociateExternalConnectionResponse.Builder,AssociateExternalConnectionResponse>
@Generated("software.amazon.awssdk:codegen")
public final class AssociateExternalConnectionResponse
extends CodeartifactResponse
implements ToCopyableBuilder<AssociateExternalConnectionResponse.Builder,AssociateExternalConnectionResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final RepositoryDescriptionInformation about the connected repository after processing the request.static Class<? extends AssociateExternalConnectionResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.codeartifact.model.CodeartifactResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
repository
Information about the connected repository after processing the request.
- Returns:
- Information about the connected repository after processing the request.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AssociateExternalConnectionResponse.Builder,AssociateExternalConnectionResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends AssociateExternalConnectionResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-