Class CreatePackageGroupRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<CreatePackageGroupRequest.Builder,CreatePackageGroupRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringThe contact information for the created package group.final StringA description of the package group.final Stringdomain()The name of the domain in which you want to create a package group.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanhasTags()For responses, this returns true if the service returned a value for the Tags property.final StringThe pattern of the package group to create.static Class<? extends CreatePackageGroupRequest.Builder>tags()One or more tag key-value pairs for the package group.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain in which you want to create a package group.
- Returns:
- The name of the domain in which you want to create a package group.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
packageGroup
The pattern of the package group to create. The pattern is also the identifier of the package group.
- Returns:
- The pattern of the package group to create. The pattern is also the identifier of the package group.
-
contactInfo
The contact information for the created package group.
- Returns:
- The contact information for the created package group.
-
description
A description of the package group.
- Returns:
- A description of the package group.
-
hasTags
public final boolean hasTags()For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
tags
One or more tag key-value pairs for the package group.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasTags()method.- Returns:
- One or more tag key-value pairs for the package group.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<CreatePackageGroupRequest.Builder,CreatePackageGroupRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-