Interface CreatePackageGroupRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CodeartifactRequest.Builder,CopyableBuilder<CreatePackageGroupRequest.Builder,,CreatePackageGroupRequest> SdkBuilder<CreatePackageGroupRequest.Builder,,CreatePackageGroupRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- CreatePackageGroupRequest
@Mutable
@NotThreadSafe
public static interface CreatePackageGroupRequest.Builder
extends CodeartifactRequest.Builder, SdkPojo, CopyableBuilder<CreatePackageGroupRequest.Builder,CreatePackageGroupRequest>
-
Method Summary
Modifier and TypeMethodDescriptioncontactInfo(String contactInfo) The contact information for the created package group.description(String description) A description of the package group.The name of the domain in which you want to create a package group.domainOwner(String domainOwner) The 12-digit account number of the Amazon Web Services account that owns the domain.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) packageGroup(String packageGroup) The pattern of the package group to create.tags(Collection<Tag> tags) One or more tag key-value pairs for the package group.tags(Consumer<Tag.Builder>... tags) One or more tag key-value pairs for the package group.One or more tag key-value pairs for the package group.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
domain
The name of the domain in which you want to create a package group.
- Parameters:
domain- The name of the domain in which you want to create a package group.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Parameters:
domainOwner- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
packageGroup
The pattern of the package group to create. The pattern is also the identifier of the package group.
- Parameters:
packageGroup- The pattern of the package group to create. The pattern is also the identifier of the package group.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
contactInfo
The contact information for the created package group.
- Parameters:
contactInfo- The contact information for the created package group.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
description
A description of the package group.
- Parameters:
description- A description of the package group.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
tags
One or more tag key-value pairs for the package group.
- Parameters:
tags- One or more tag key-value pairs for the package group.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
tags
One or more tag key-value pairs for the package group.
- Parameters:
tags- One or more tag key-value pairs for the package group.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
tags
One or more tag key-value pairs for the package group.
This is a convenience method that creates an instance of theTag.Builderavoiding the need to create one manually viaTag.builder().When the
Consumercompletes,SdkBuilder.build()is called immediately and its result is passed totags(List<Tag>).- Parameters:
tags- a consumer that will call methods onTag.Builder- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
overrideConfiguration
CreatePackageGroupRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
CreatePackageGroupRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-