Class CreateRepositoryRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<CreateRepositoryRequest.Builder,CreateRepositoryRequest>

@Generated("software.amazon.awssdk:codegen") public final class CreateRepositoryRequest extends CodeartifactRequest implements ToCopyableBuilder<CreateRepositoryRequest.Builder,CreateRepositoryRequest>
  • Method Details

    • domain

      public final String domain()

      The name of the domain that contains the created repository.

      Returns:
      The name of the domain that contains the created repository.
    • domainOwner

      public final String domainOwner()

      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

      Returns:
      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
    • repository

      public final String repository()

      The name of the repository to create.

      Returns:
      The name of the repository to create.
    • description

      public final String description()

      A description of the created repository.

      Returns:
      A description of the created repository.
    • hasUpstreams

      public final boolean hasUpstreams()
      For responses, this returns true if the service returned a value for the Upstreams property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • upstreams

      public final List<UpstreamRepository> upstreams()

      A list of upstream repositories to associate with the repository. The order of the upstream repositories in the list determines their priority order when CodeArtifact looks for a requested package version. For more information, see Working with upstream repositories.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasUpstreams() method.

      Returns:
      A list of upstream repositories to associate with the repository. The order of the upstream repositories in the list determines their priority order when CodeArtifact looks for a requested package version. For more information, see Working with upstream repositories.
    • hasTags

      public final boolean hasTags()
      For responses, this returns true if the service returned a value for the Tags property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • tags

      public final List<Tag> tags()

      One or more tag key-value pairs for the repository.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasTags() method.

      Returns:
      One or more tag key-value pairs for the repository.
    • toBuilder

      public CreateRepositoryRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<CreateRepositoryRequest.Builder,CreateRepositoryRequest>
      Specified by:
      toBuilder in class CodeartifactRequest
    • builder

      public static CreateRepositoryRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends CreateRepositoryRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo