Class DeletePackageVersionsRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<DeletePackageVersionsRequest.Builder,DeletePackageVersionsRequest>

@Generated("software.amazon.awssdk:codegen") public final class DeletePackageVersionsRequest extends CodeartifactRequest implements ToCopyableBuilder<DeletePackageVersionsRequest.Builder,DeletePackageVersionsRequest>
  • Method Details

    • domain

      public final String domain()

      The name of the domain that contains the package to delete.

      Returns:
      The name of the domain that contains the package to delete.
    • domainOwner

      public final String domainOwner()

      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

      Returns:
      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
    • repository

      public final String repository()

      The name of the repository that contains the package versions to delete.

      Returns:
      The name of the repository that contains the package versions to delete.
    • format

      public final PackageFormat format()

      The format of the package versions to delete.

      If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

      Returns:
      The format of the package versions to delete.
      See Also:
    • formatAsString

      public final String formatAsString()

      The format of the package versions to delete.

      If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

      Returns:
      The format of the package versions to delete.
      See Also:
    • namespace

      public final String namespace()

      The namespace of the package versions to be deleted. The package component that specifies its namespace depends on its type. For example:

      The namespace is required when deleting package versions of the following formats:

      • Maven

      • Swift

      • generic

      • The namespace of a Maven package version is its groupId.

      • The namespace of an npm or Swift package version is its scope.

      • The namespace of a generic package is its namespace.

      • Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.

      Returns:
      The namespace of the package versions to be deleted. The package component that specifies its namespace depends on its type. For example:

      The namespace is required when deleting package versions of the following formats:

      • Maven

      • Swift

      • generic

      • The namespace of a Maven package version is its groupId.

      • The namespace of an npm or Swift package version is its scope.

      • The namespace of a generic package is its namespace.

      • Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.

    • packageValue

      public final String packageValue()

      The name of the package with the versions to delete.

      Returns:
      The name of the package with the versions to delete.
    • hasVersions

      public final boolean hasVersions()
      For responses, this returns true if the service returned a value for the Versions property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • versions

      public final List<String> versions()

      An array of strings that specify the versions of the package to delete.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasVersions() method.

      Returns:
      An array of strings that specify the versions of the package to delete.
    • expectedStatus

      public final PackageVersionStatus expectedStatus()

      The expected status of the package version to delete.

      If the service returns an enum value that is not available in the current SDK version, expectedStatus will return PackageVersionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from expectedStatusAsString().

      Returns:
      The expected status of the package version to delete.
      See Also:
    • expectedStatusAsString

      public final String expectedStatusAsString()

      The expected status of the package version to delete.

      If the service returns an enum value that is not available in the current SDK version, expectedStatus will return PackageVersionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from expectedStatusAsString().

      Returns:
      The expected status of the package version to delete.
      See Also:
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<DeletePackageVersionsRequest.Builder,DeletePackageVersionsRequest>
      Specified by:
      toBuilder in class CodeartifactRequest
    • builder

      public static DeletePackageVersionsRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends DeletePackageVersionsRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo