Class DeleteRepositoryPermissionsPolicyRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<DeleteRepositoryPermissionsPolicyRequest.Builder,DeleteRepositoryPermissionsPolicyRequest>

@Generated("software.amazon.awssdk:codegen") public final class DeleteRepositoryPermissionsPolicyRequest extends CodeartifactRequest implements ToCopyableBuilder<DeleteRepositoryPermissionsPolicyRequest.Builder,DeleteRepositoryPermissionsPolicyRequest>
  • Method Details

    • domain

      public final String domain()

      The name of the domain that contains the repository associated with the resource policy to be deleted.

      Returns:
      The name of the domain that contains the repository associated with the resource policy to be deleted.
    • domainOwner

      public final String domainOwner()

      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

      Returns:
      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
    • repository

      public final String repository()

      The name of the repository that is associated with the resource policy to be deleted

      Returns:
      The name of the repository that is associated with the resource policy to be deleted
    • policyRevision

      public final String policyRevision()

      The revision of the repository's resource policy to be deleted. This revision is used for optimistic locking, which prevents others from accidentally overwriting your changes to the repository's resource policy.

      Returns:
      The revision of the repository's resource policy to be deleted. This revision is used for optimistic locking, which prevents others from accidentally overwriting your changes to the repository's resource policy.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<DeleteRepositoryPermissionsPolicyRequest.Builder,DeleteRepositoryPermissionsPolicyRequest>
      Specified by:
      toBuilder in class CodeartifactRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends DeleteRepositoryPermissionsPolicyRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo