Interface DescribeDomainRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CodeartifactRequest.Builder,CopyableBuilder<DescribeDomainRequest.Builder,,DescribeDomainRequest> SdkBuilder<DescribeDomainRequest.Builder,,DescribeDomainRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- DescribeDomainRequest
@Mutable
@NotThreadSafe
public static interface DescribeDomainRequest.Builder
extends CodeartifactRequest.Builder, SdkPojo, CopyableBuilder<DescribeDomainRequest.Builder,DescribeDomainRequest>
-
Method Summary
Modifier and TypeMethodDescriptionA string that specifies the name of the requested domain.domainOwner(String domainOwner) The 12-digit account number of the Amazon Web Services account that owns the domain.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
domain
A string that specifies the name of the requested domain.
- Parameters:
domain- A string that specifies the name of the requested domain.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Parameters:
domainOwner- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
DescribeDomainRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
DescribeDomainRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-