Class DescribePackageVersionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DescribePackageVersionRequest.Builder,DescribePackageVersionRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringdomain()The name of the domain that contains the repository that contains the package version.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final PackageFormatformat()A format that specifies the type of the requested package version.final StringA format that specifies the type of the requested package version.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe namespace of the requested package version.final StringThe name of the requested package version.final StringA string that contains the package version (for example,3.5.2).final StringThe name of the repository that contains the package version.static Class<? extends DescribePackageVersionRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain that contains the repository that contains the package version.
- Returns:
- The name of the domain that contains the repository that contains the package version.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
repository
The name of the repository that contains the package version.
- Returns:
- The name of the repository that contains the package version.
-
format
A format that specifies the type of the requested package version.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- A format that specifies the type of the requested package version.
- See Also:
-
formatAsString
A format that specifies the type of the requested package version.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- A format that specifies the type of the requested package version.
- See Also:
-
namespace
The namespace of the requested package version. The package component that specifies its namespace depends on its type. For example:
The namespace is required when requesting package versions of the following formats:
-
Maven
-
Swift
-
generic
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
- Returns:
- The namespace of the requested package version. The package component that specifies its namespace
depends on its type. For example:
The namespace is required when requesting package versions of the following formats:
-
Maven
-
Swift
-
generic
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
-
-
-
packageValue
The name of the requested package version.
- Returns:
- The name of the requested package version.
-
packageVersion
A string that contains the package version (for example,
3.5.2).- Returns:
- A string that contains the package version (for example,
3.5.2).
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DescribePackageVersionRequest.Builder,DescribePackageVersionRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-