Interface DescribeRepositoryRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CodeartifactRequest.Builder,CopyableBuilder<DescribeRepositoryRequest.Builder,,DescribeRepositoryRequest> SdkBuilder<DescribeRepositoryRequest.Builder,,DescribeRepositoryRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- DescribeRepositoryRequest
@Mutable
@NotThreadSafe
public static interface DescribeRepositoryRequest.Builder
extends CodeartifactRequest.Builder, SdkPojo, CopyableBuilder<DescribeRepositoryRequest.Builder,DescribeRepositoryRequest>
-
Method Summary
Modifier and TypeMethodDescriptionThe name of the domain that contains the repository to describe.domainOwner(String domainOwner) The 12-digit account number of the Amazon Web Services account that owns the domain.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) repository(String repository) A string that specifies the name of the requested repository.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
domain
The name of the domain that contains the repository to describe.
- Parameters:
domain- The name of the domain that contains the repository to describe.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Parameters:
domainOwner- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
repository
A string that specifies the name of the requested repository.
- Parameters:
repository- A string that specifies the name of the requested repository.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
DescribeRepositoryRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
DescribeRepositoryRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-