Class DisassociateExternalConnectionRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest
software.amazon.awssdk.services.codeartifact.model.DisassociateExternalConnectionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DisassociateExternalConnectionRequest.Builder,DisassociateExternalConnectionRequest>
@Generated("software.amazon.awssdk:codegen")
public final class DisassociateExternalConnectionRequest
extends CodeartifactRequest
implements ToCopyableBuilder<DisassociateExternalConnectionRequest.Builder,DisassociateExternalConnectionRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringdomain()The name of the domain that contains the repository from which to remove the external repository.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name of the external connection to be removed from the repository.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe name of the repository from which the external connection will be removed.static Class<? extends DisassociateExternalConnectionRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain that contains the repository from which to remove the external repository.
- Returns:
- The name of the domain that contains the repository from which to remove the external repository.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
repository
The name of the repository from which the external connection will be removed.
- Returns:
- The name of the repository from which the external connection will be removed.
-
externalConnection
The name of the external connection to be removed from the repository.
- Returns:
- The name of the external connection to be removed from the repository.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DisassociateExternalConnectionRequest.Builder,DisassociateExternalConnectionRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
public static Class<? extends DisassociateExternalConnectionRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-