Interface DisassociateExternalConnectionRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CodeartifactRequest.Builder,CopyableBuilder<DisassociateExternalConnectionRequest.Builder,,DisassociateExternalConnectionRequest> SdkBuilder<DisassociateExternalConnectionRequest.Builder,,DisassociateExternalConnectionRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- DisassociateExternalConnectionRequest
@Mutable
@NotThreadSafe
public static interface DisassociateExternalConnectionRequest.Builder
extends CodeartifactRequest.Builder, SdkPojo, CopyableBuilder<DisassociateExternalConnectionRequest.Builder,DisassociateExternalConnectionRequest>
-
Method Summary
Modifier and TypeMethodDescriptionThe name of the domain that contains the repository from which to remove the external repository.domainOwner(String domainOwner) The 12-digit account number of the Amazon Web Services account that owns the domain.externalConnection(String externalConnection) The name of the external connection to be removed from the repository.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) repository(String repository) The name of the repository from which the external connection will be removed.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
domain
The name of the domain that contains the repository from which to remove the external repository.
- Parameters:
domain- The name of the domain that contains the repository from which to remove the external repository.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Parameters:
domainOwner- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
repository
The name of the repository from which the external connection will be removed.
- Parameters:
repository- The name of the repository from which the external connection will be removed.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
externalConnection
The name of the external connection to be removed from the repository.
- Parameters:
externalConnection- The name of the external connection to be removed from the repository.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
DisassociateExternalConnectionRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
DisassociateExternalConnectionRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-