Class DisposePackageVersionsRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<DisposePackageVersionsRequest.Builder,DisposePackageVersionsRequest>

@Generated("software.amazon.awssdk:codegen") public final class DisposePackageVersionsRequest extends CodeartifactRequest implements ToCopyableBuilder<DisposePackageVersionsRequest.Builder,DisposePackageVersionsRequest>
  • Method Details

    • domain

      public final String domain()

      The name of the domain that contains the repository you want to dispose.

      Returns:
      The name of the domain that contains the repository you want to dispose.
    • domainOwner

      public final String domainOwner()

      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

      Returns:
      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
    • repository

      public final String repository()

      The name of the repository that contains the package versions you want to dispose.

      Returns:
      The name of the repository that contains the package versions you want to dispose.
    • format

      public final PackageFormat format()

      A format that specifies the type of package versions you want to dispose.

      If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

      Returns:
      A format that specifies the type of package versions you want to dispose.
      See Also:
    • formatAsString

      public final String formatAsString()

      A format that specifies the type of package versions you want to dispose.

      If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

      Returns:
      A format that specifies the type of package versions you want to dispose.
      See Also:
    • namespace

      public final String namespace()

      The namespace of the package versions to be disposed. The package component that specifies its namespace depends on its type. For example:

      The namespace is required when disposing package versions of the following formats:

      • Maven

      • Swift

      • generic

      • The namespace of a Maven package version is its groupId.

      • The namespace of an npm or Swift package version is its scope.

      • The namespace of a generic package is its namespace.

      • Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.

      Returns:
      The namespace of the package versions to be disposed. The package component that specifies its namespace depends on its type. For example:

      The namespace is required when disposing package versions of the following formats:

      • Maven

      • Swift

      • generic

      • The namespace of a Maven package version is its groupId.

      • The namespace of an npm or Swift package version is its scope.

      • The namespace of a generic package is its namespace.

      • Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.

    • packageValue

      public final String packageValue()

      The name of the package with the versions you want to dispose.

      Returns:
      The name of the package with the versions you want to dispose.
    • hasVersions

      public final boolean hasVersions()
      For responses, this returns true if the service returned a value for the Versions property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • versions

      public final List<String> versions()

      The versions of the package you want to dispose.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasVersions() method.

      Returns:
      The versions of the package you want to dispose.
    • hasVersionRevisions

      public final boolean hasVersionRevisions()
      For responses, this returns true if the service returned a value for the VersionRevisions property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • versionRevisions

      public final Map<String,String> versionRevisions()

      The revisions of the package versions you want to dispose.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasVersionRevisions() method.

      Returns:
      The revisions of the package versions you want to dispose.
    • expectedStatus

      public final PackageVersionStatus expectedStatus()

      The expected status of the package version to dispose.

      If the service returns an enum value that is not available in the current SDK version, expectedStatus will return PackageVersionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from expectedStatusAsString().

      Returns:
      The expected status of the package version to dispose.
      See Also:
    • expectedStatusAsString

      public final String expectedStatusAsString()

      The expected status of the package version to dispose.

      If the service returns an enum value that is not available in the current SDK version, expectedStatus will return PackageVersionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from expectedStatusAsString().

      Returns:
      The expected status of the package version to dispose.
      See Also:
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<DisposePackageVersionsRequest.Builder,DisposePackageVersionsRequest>
      Specified by:
      toBuilder in class CodeartifactRequest
    • builder

      public static DisposePackageVersionsRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends DisposePackageVersionsRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo