Class DomainDescription
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<DomainDescription.Builder,DomainDescription>
Information about a domain. A domain is a container for repositories. When you create a domain, it is empty until you add one or more repositories.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Stringarn()The Amazon Resource Name (ARN) of the domain.final LongThe total size of all assets in the domain.static DomainDescription.Builderbuilder()final InstantA timestamp that represents the date and time the domain was created.final StringThe ARN of an Key Management Service (KMS) key associated with a domain.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name of the domain.final Stringowner()The Amazon Web Services account ID that owns the domain.final IntegerThe number of repositories in the domain.final StringThe Amazon Resource Name (ARN) of the Amazon S3 bucket that is used to store package assets in the domain.static Class<? extends DomainDescription.Builder>final DomainStatusstatus()The current status of a domain.final StringThe current status of a domain.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the domain.
- Returns:
- The name of the domain.
-
owner
The Amazon Web Services account ID that owns the domain.
- Returns:
- The Amazon Web Services account ID that owns the domain.
-
arn
The Amazon Resource Name (ARN) of the domain.
- Returns:
- The Amazon Resource Name (ARN) of the domain.
-
status
The current status of a domain.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnDomainStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The current status of a domain.
- See Also:
-
statusAsString
The current status of a domain.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnDomainStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The current status of a domain.
- See Also:
-
createdTime
A timestamp that represents the date and time the domain was created.
- Returns:
- A timestamp that represents the date and time the domain was created.
-
encryptionKey
The ARN of an Key Management Service (KMS) key associated with a domain.
- Returns:
- The ARN of an Key Management Service (KMS) key associated with a domain.
-
repositoryCount
The number of repositories in the domain.
- Returns:
- The number of repositories in the domain.
-
assetSizeBytes
The total size of all assets in the domain.
- Returns:
- The total size of all assets in the domain.
-
s3BucketArn
The Amazon Resource Name (ARN) of the Amazon S3 bucket that is used to store package assets in the domain.
- Returns:
- The Amazon Resource Name (ARN) of the Amazon S3 bucket that is used to store package assets in the domain.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DomainDescription.Builder,DomainDescription>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-