Class DomainEntryPoint
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<DomainEntryPoint.Builder,DomainEntryPoint>
Information about how a package originally entered the CodeArtifact domain. For packages published directly to CodeArtifact, the entry point is the repository it was published to. For packages ingested from an external repository, the entry point is the external connection that it was ingested from. An external connection is a CodeArtifact repository that is connected to an external repository such as the npm registry or NuGet gallery.
If a package version exists in a repository and is updated, for example if a package of the same version is added
with additional assets, the package version's DomainEntryPoint will not change from the original package
version's value.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic DomainEntryPoint.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name of the external connection that a package was ingested from.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe name of the repository that a package was originally published to.static Class<? extends DomainEntryPoint.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
repositoryName
The name of the repository that a package was originally published to.
- Returns:
- The name of the repository that a package was originally published to.
-
externalConnectionName
The name of the external connection that a package was ingested from.
- Returns:
- The name of the external connection that a package was ingested from.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DomainEntryPoint.Builder,DomainEntryPoint>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-