Class DomainSummary
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<DomainSummary.Builder,DomainSummary>
Information about a domain, including its name, Amazon Resource Name (ARN), and status. The ListDomains operation
returns a list of DomainSummary objects.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Stringarn()The ARN of the domain.static DomainSummary.Builderbuilder()final InstantA timestamp that contains the date and time the domain was created.final StringThe key used to encrypt the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name of the domain.final Stringowner()The 12-digit account number of the Amazon Web Services account that owns the domain.static Class<? extends DomainSummary.Builder>final DomainStatusstatus()A string that contains the status of the domain.final StringA string that contains the status of the domain.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the domain.
- Returns:
- The name of the domain.
-
owner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
arn
The ARN of the domain.
- Returns:
- The ARN of the domain.
-
status
A string that contains the status of the domain.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnDomainStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- A string that contains the status of the domain.
- See Also:
-
statusAsString
A string that contains the status of the domain.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnDomainStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- A string that contains the status of the domain.
- See Also:
-
createdTime
A timestamp that contains the date and time the domain was created.
- Returns:
- A timestamp that contains the date and time the domain was created.
-
encryptionKey
The key used to encrypt the domain.
- Returns:
- The key used to encrypt the domain.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DomainSummary.Builder,DomainSummary>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-