Interface GetAssociatedPackageGroupRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CodeartifactRequest.Builder,CopyableBuilder<GetAssociatedPackageGroupRequest.Builder,,GetAssociatedPackageGroupRequest> SdkBuilder<GetAssociatedPackageGroupRequest.Builder,,GetAssociatedPackageGroupRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- GetAssociatedPackageGroupRequest
-
Method Summary
Modifier and TypeMethodDescriptionThe name of the domain that contains the package from which to get the associated package group.domainOwner(String domainOwner) The 12-digit account number of the Amazon Web Services account that owns the domain.The format of the package from which to get the associated package group.format(PackageFormat format) The format of the package from which to get the associated package group.The namespace of the package from which to get the associated package group.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) packageValue(String packageValue) The package from which to get the associated package group.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
domain
The name of the domain that contains the package from which to get the associated package group.
- Parameters:
domain- The name of the domain that contains the package from which to get the associated package group.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Parameters:
domainOwner- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
format
The format of the package from which to get the associated package group.
- Parameters:
format- The format of the package from which to get the associated package group.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
format
The format of the package from which to get the associated package group.
- Parameters:
format- The format of the package from which to get the associated package group.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
namespace
The namespace of the package from which to get the associated package group. The package component that specifies its namespace depends on its type. For example:
The namespace is required when getting associated package groups from packages of the following formats:
-
Maven
-
Swift
-
generic
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
- Parameters:
namespace- The namespace of the package from which to get the associated package group. The package component that specifies its namespace depends on its type. For example:The namespace is required when getting associated package groups from packages of the following formats:
-
Maven
-
Swift
-
generic
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
-
- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
-
packageValue
The package from which to get the associated package group.
- Parameters:
packageValue- The package from which to get the associated package group.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
GetAssociatedPackageGroupRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
GetAssociatedPackageGroupRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-