Class GetAuthorizationTokenRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetAuthorizationTokenRequest.Builder,GetAuthorizationTokenRequest>

@Generated("software.amazon.awssdk:codegen") public final class GetAuthorizationTokenRequest extends CodeartifactRequest implements ToCopyableBuilder<GetAuthorizationTokenRequest.Builder,GetAuthorizationTokenRequest>
  • Method Details

    • domain

      public final String domain()

      The name of the domain that is in scope for the generated authorization token.

      Returns:
      The name of the domain that is in scope for the generated authorization token.
    • domainOwner

      public final String domainOwner()

      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

      Returns:
      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
    • durationSeconds

      public final Long durationSeconds()

      The time, in seconds, that the generated authorization token is valid. Valid values are 0 and any number between 900 (15 minutes) and 43200 (12 hours). A value of 0 will set the expiration of the authorization token to the same expiration of the user's role's temporary credentials.

      Returns:
      The time, in seconds, that the generated authorization token is valid. Valid values are 0 and any number between 900 (15 minutes) and 43200 (12 hours). A value of 0 will set the expiration of the authorization token to the same expiration of the user's role's temporary credentials.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<GetAuthorizationTokenRequest.Builder,GetAuthorizationTokenRequest>
      Specified by:
      toBuilder in class CodeartifactRequest
    • builder

      public static GetAuthorizationTokenRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetAuthorizationTokenRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo