Interface GetAuthorizationTokenRequest.Builder

All Superinterfaces:
AwsRequest.Builder, Buildable, CodeartifactRequest.Builder, CopyableBuilder<GetAuthorizationTokenRequest.Builder,GetAuthorizationTokenRequest>, SdkBuilder<GetAuthorizationTokenRequest.Builder,GetAuthorizationTokenRequest>, SdkPojo, SdkRequest.Builder
Enclosing class:
GetAuthorizationTokenRequest

  • Method Details

    • domain

      The name of the domain that is in scope for the generated authorization token.

      Parameters:
      domain - The name of the domain that is in scope for the generated authorization token.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • domainOwner

      GetAuthorizationTokenRequest.Builder domainOwner(String domainOwner)

      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

      Parameters:
      domainOwner - The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • durationSeconds

      GetAuthorizationTokenRequest.Builder durationSeconds(Long durationSeconds)

      The time, in seconds, that the generated authorization token is valid. Valid values are 0 and any number between 900 (15 minutes) and 43200 (12 hours). A value of 0 will set the expiration of the authorization token to the same expiration of the user's role's temporary credentials.

      Parameters:
      durationSeconds - The time, in seconds, that the generated authorization token is valid. Valid values are 0 and any number between 900 (15 minutes) and 43200 (12 hours). A value of 0 will set the expiration of the authorization token to the same expiration of the user's role's temporary credentials.
      Returns:
      Returns a reference to this object so that method calls can be chained together.
    • overrideConfiguration

      GetAuthorizationTokenRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration)
      Specified by:
      overrideConfiguration in interface AwsRequest.Builder
    • overrideConfiguration

      Specified by:
      overrideConfiguration in interface AwsRequest.Builder