Class GetAuthorizationTokenResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.codeartifact.model.CodeartifactResponse
software.amazon.awssdk.services.codeartifact.model.GetAuthorizationTokenResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetAuthorizationTokenResponse.Builder,GetAuthorizationTokenResponse>
@Generated("software.amazon.awssdk:codegen")
public final class GetAuthorizationTokenResponse
extends CodeartifactResponse
implements ToCopyableBuilder<GetAuthorizationTokenResponse.Builder,GetAuthorizationTokenResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe returned authentication token.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final InstantA timestamp that specifies the date and time the authorization token expires.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends GetAuthorizationTokenResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.codeartifact.model.CodeartifactResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
authorizationToken
The returned authentication token.
- Returns:
- The returned authentication token.
-
expiration
A timestamp that specifies the date and time the authorization token expires.
- Returns:
- A timestamp that specifies the date and time the authorization token expires.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetAuthorizationTokenResponse.Builder,GetAuthorizationTokenResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-