Class GetPackageVersionAssetResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.codeartifact.model.CodeartifactResponse
software.amazon.awssdk.services.codeartifact.model.GetPackageVersionAssetResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetPackageVersionAssetResponse.Builder,GetPackageVersionAssetResponse>
@Generated("software.amazon.awssdk:codegen")
public final class GetPackageVersionAssetResponse
extends CodeartifactResponse
implements ToCopyableBuilder<GetPackageVersionAssetResponse.Builder,GetPackageVersionAssetResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe name of the asset that is downloaded.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringA string that contains the package version (for example,3.5.2).final StringThe name of the package version revision that contains the downloaded asset.static Class<? extends GetPackageVersionAssetResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.codeartifact.model.CodeartifactResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
assetName
The name of the asset that is downloaded.
- Returns:
- The name of the asset that is downloaded.
-
packageVersion
A string that contains the package version (for example,
3.5.2).- Returns:
- A string that contains the package version (for example,
3.5.2).
-
packageVersionRevision
The name of the package version revision that contains the downloaded asset.
- Returns:
- The name of the package version revision that contains the downloaded asset.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetPackageVersionAssetResponse.Builder,GetPackageVersionAssetResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-