Class GetPackageVersionReadmeRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetPackageVersionReadmeRequest.Builder,GetPackageVersionReadmeRequest>

@Generated("software.amazon.awssdk:codegen") public final class GetPackageVersionReadmeRequest extends CodeartifactRequest implements ToCopyableBuilder<GetPackageVersionReadmeRequest.Builder,GetPackageVersionReadmeRequest>
  • Method Details

    • domain

      public final String domain()

      The name of the domain that contains the repository that contains the package version with the requested readme file.

      Returns:
      The name of the domain that contains the repository that contains the package version with the requested readme file.
    • domainOwner

      public final String domainOwner()

      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

      Returns:
      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
    • repository

      public final String repository()

      The repository that contains the package with the requested readme file.

      Returns:
      The repository that contains the package with the requested readme file.
    • format

      public final PackageFormat format()

      A format that specifies the type of the package version with the requested readme file.

      If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

      Returns:
      A format that specifies the type of the package version with the requested readme file.
      See Also:
    • formatAsString

      public final String formatAsString()

      A format that specifies the type of the package version with the requested readme file.

      If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

      Returns:
      A format that specifies the type of the package version with the requested readme file.
      See Also:
    • namespace

      public final String namespace()

      The namespace of the package version with the requested readme file. The package component that specifies its namespace depends on its type. For example:

      The namespace is required when requesting the readme from package versions of the following formats:

      • Maven

      • Swift

      • generic

      • The namespace of a Maven package version is its groupId.

      • The namespace of an npm or Swift package version is its scope.

      • The namespace of a generic package is its namespace.

      • Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.

      Returns:
      The namespace of the package version with the requested readme file. The package component that specifies its namespace depends on its type. For example:

      The namespace is required when requesting the readme from package versions of the following formats:

      • Maven

      • Swift

      • generic

      • The namespace of a Maven package version is its groupId.

      • The namespace of an npm or Swift package version is its scope.

      • The namespace of a generic package is its namespace.

      • Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.

    • packageValue

      public final String packageValue()

      The name of the package version that contains the requested readme file.

      Returns:
      The name of the package version that contains the requested readme file.
    • packageVersion

      public final String packageVersion()

      A string that contains the package version (for example, 3.5.2).

      Returns:
      A string that contains the package version (for example, 3.5.2).
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<GetPackageVersionReadmeRequest.Builder,GetPackageVersionReadmeRequest>
      Specified by:
      toBuilder in class CodeartifactRequest
    • builder

      public static GetPackageVersionReadmeRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetPackageVersionReadmeRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo