Class GetPackageVersionReadmeResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetPackageVersionReadmeResponse.Builder,GetPackageVersionReadmeResponse>

@Generated("software.amazon.awssdk:codegen") public final class GetPackageVersionReadmeResponse extends CodeartifactResponse implements ToCopyableBuilder<GetPackageVersionReadmeResponse.Builder,GetPackageVersionReadmeResponse>
  • Method Details

    • format

      public final PackageFormat format()

      The format of the package with the requested readme file.

      If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

      Returns:
      The format of the package with the requested readme file.
      See Also:
    • formatAsString

      public final String formatAsString()

      The format of the package with the requested readme file.

      If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

      Returns:
      The format of the package with the requested readme file.
      See Also:
    • namespace

      public final String namespace()

      The namespace of the package version with the requested readme file. The package component that specifies its namespace depends on its type. For example:

      • The namespace of a Maven package version is its groupId.

      • The namespace of an npm or Swift package version is its scope.

      • The namespace of a generic package is its namespace.

      • Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.

      Returns:
      The namespace of the package version with the requested readme file. The package component that specifies its namespace depends on its type. For example:

      • The namespace of a Maven package version is its groupId.

      • The namespace of an npm or Swift package version is its scope.

      • The namespace of a generic package is its namespace.

      • Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.

    • packageValue

      public final String packageValue()

      The name of the package that contains the returned readme file.

      Returns:
      The name of the package that contains the returned readme file.
    • version

      public final String version()

      The version of the package with the requested readme file.

      Returns:
      The version of the package with the requested readme file.
    • versionRevision

      public final String versionRevision()

      The current revision associated with the package version.

      Returns:
      The current revision associated with the package version.
    • readme

      public final String readme()

      The text of the returned readme file.

      Returns:
      The text of the returned readme file.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<GetPackageVersionReadmeResponse.Builder,GetPackageVersionReadmeResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

      public static GetPackageVersionReadmeResponse.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetPackageVersionReadmeResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo