Class GetRepositoryEndpointRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetRepositoryEndpointRequest.Builder,GetRepositoryEndpointRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringdomain()The name of the domain that contains the repository.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain that contains the repository.final EndpointTypeA string that specifies the type of endpoint.final StringA string that specifies the type of endpoint.final booleanfinal booleanequalsBySdkFields(Object obj) final PackageFormatformat()Returns which endpoint of a repository to return.final StringReturns which endpoint of a repository to return.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe name of the repository.static Class<? extends GetRepositoryEndpointRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain that contains the repository.
- Returns:
- The name of the domain that contains the repository.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain that contains the repository. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain that contains the repository. It does not include dashes or spaces.
-
repository
The name of the repository.
- Returns:
- The name of the repository.
-
format
Returns which endpoint of a repository to return. A repository has one endpoint for each package format.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- Returns which endpoint of a repository to return. A repository has one endpoint for each package format.
- See Also:
-
formatAsString
Returns which endpoint of a repository to return. A repository has one endpoint for each package format.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- Returns which endpoint of a repository to return. A repository has one endpoint for each package format.
- See Also:
-
endpointType
A string that specifies the type of endpoint.
If the service returns an enum value that is not available in the current SDK version,
endpointTypewill returnEndpointType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromendpointTypeAsString().- Returns:
- A string that specifies the type of endpoint.
- See Also:
-
endpointTypeAsString
A string that specifies the type of endpoint.
If the service returns an enum value that is not available in the current SDK version,
endpointTypewill returnEndpointType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromendpointTypeAsString().- Returns:
- A string that specifies the type of endpoint.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetRepositoryEndpointRequest.Builder,GetRepositoryEndpointRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-