Interface GetRepositoryPermissionsPolicyRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CodeartifactRequest.Builder,CopyableBuilder<GetRepositoryPermissionsPolicyRequest.Builder,,GetRepositoryPermissionsPolicyRequest> SdkBuilder<GetRepositoryPermissionsPolicyRequest.Builder,,GetRepositoryPermissionsPolicyRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- GetRepositoryPermissionsPolicyRequest
@Mutable
@NotThreadSafe
public static interface GetRepositoryPermissionsPolicyRequest.Builder
extends CodeartifactRequest.Builder, SdkPojo, CopyableBuilder<GetRepositoryPermissionsPolicyRequest.Builder,GetRepositoryPermissionsPolicyRequest>
-
Method Summary
Modifier and TypeMethodDescriptionThe name of the domain containing the repository whose associated resource policy is to be retrieved.domainOwner(String domainOwner) The 12-digit account number of the Amazon Web Services account that owns the domain.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) repository(String repository) The name of the repository whose associated resource policy is to be retrieved.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
domain
The name of the domain containing the repository whose associated resource policy is to be retrieved.
- Parameters:
domain- The name of the domain containing the repository whose associated resource policy is to be retrieved.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Parameters:
domainOwner- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
repository
The name of the repository whose associated resource policy is to be retrieved.
- Parameters:
repository- The name of the repository whose associated resource policy is to be retrieved.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
GetRepositoryPermissionsPolicyRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
GetRepositoryPermissionsPolicyRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-