Class ListPackageGroupsRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ListPackageGroupsRequest.Builder,ListPackageGroupsRequest>

@Generated("software.amazon.awssdk:codegen") public final class ListPackageGroupsRequest extends CodeartifactRequest implements ToCopyableBuilder<ListPackageGroupsRequest.Builder,ListPackageGroupsRequest>
  • Method Details

    • domain

      public final String domain()

      The domain for which you want to list package groups.

      Returns:
      The domain for which you want to list package groups.
    • domainOwner

      public final String domainOwner()

      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

      Returns:
      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
    • maxResults

      public final Integer maxResults()

      The maximum number of results to return per page.

      Returns:
      The maximum number of results to return per page.
    • nextToken

      public final String nextToken()

      The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

      Returns:
      The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
    • prefix

      public final String prefix()

      A prefix for which to search package groups. When included, ListPackageGroups will return only package groups with patterns that match the prefix.

      Returns:
      A prefix for which to search package groups. When included, ListPackageGroups will return only package groups with patterns that match the prefix.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<ListPackageGroupsRequest.Builder,ListPackageGroupsRequest>
      Specified by:
      toBuilder in class CodeartifactRequest
    • builder

      public static ListPackageGroupsRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends ListPackageGroupsRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo