Class ListPackageVersionAssetsRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ListPackageVersionAssetsRequest.Builder,ListPackageVersionAssetsRequest>

@Generated("software.amazon.awssdk:codegen") public final class ListPackageVersionAssetsRequest extends CodeartifactRequest implements ToCopyableBuilder<ListPackageVersionAssetsRequest.Builder,ListPackageVersionAssetsRequest>
  • Method Details

    • domain

      public final String domain()

      The name of the domain that contains the repository associated with the package version assets.

      Returns:
      The name of the domain that contains the repository associated with the package version assets.
    • domainOwner

      public final String domainOwner()

      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

      Returns:
      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
    • repository

      public final String repository()

      The name of the repository that contains the package that contains the requested package version assets.

      Returns:
      The name of the repository that contains the package that contains the requested package version assets.
    • format

      public final PackageFormat format()

      The format of the package that contains the requested package version assets.

      If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

      Returns:
      The format of the package that contains the requested package version assets.
      See Also:
    • formatAsString

      public final String formatAsString()

      The format of the package that contains the requested package version assets.

      If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

      Returns:
      The format of the package that contains the requested package version assets.
      See Also:
    • namespace

      public final String namespace()

      The namespace of the package version that contains the requested package version assets. The package component that specifies its namespace depends on its type. For example:

      The namespace is required requesting assets from package versions of the following formats:

      • Maven

      • Swift

      • generic

      • The namespace of a Maven package version is its groupId.

      • The namespace of an npm or Swift package version is its scope.

      • The namespace of a generic package is its namespace.

      • Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.

      Returns:
      The namespace of the package version that contains the requested package version assets. The package component that specifies its namespace depends on its type. For example:

      The namespace is required requesting assets from package versions of the following formats:

      • Maven

      • Swift

      • generic

      • The namespace of a Maven package version is its groupId.

      • The namespace of an npm or Swift package version is its scope.

      • The namespace of a generic package is its namespace.

      • Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.

    • packageValue

      public final String packageValue()

      The name of the package that contains the requested package version assets.

      Returns:
      The name of the package that contains the requested package version assets.
    • packageVersion

      public final String packageVersion()

      A string that contains the package version (for example, 3.5.2).

      Returns:
      A string that contains the package version (for example, 3.5.2).
    • maxResults

      public final Integer maxResults()

      The maximum number of results to return per page.

      Returns:
      The maximum number of results to return per page.
    • nextToken

      public final String nextToken()

      The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

      Returns:
      The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<ListPackageVersionAssetsRequest.Builder,ListPackageVersionAssetsRequest>
      Specified by:
      toBuilder in class CodeartifactRequest
    • builder

      public static ListPackageVersionAssetsRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends ListPackageVersionAssetsRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo