Class ListPackageVersionsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListPackageVersionsRequest.Builder,ListPackageVersionsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringdomain()The name of the domain that contains the repository that contains the requested package versions.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final PackageFormatformat()The format of the package versions you want to list.final StringThe format of the package versions you want to list.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe maximum number of results to return per page.final StringThe namespace of the package that contains the requested package versions.final StringThe token for the next set of results.final PackageVersionOriginTypeTheoriginTypeused to filter package versions.final StringTheoriginTypeused to filter package versions.final StringThe name of the package for which you want to request package versions.final StringThe name of the repository that contains the requested package versions.static Class<? extends ListPackageVersionsRequest.Builder>final PackageVersionSortTypesortBy()How to sort the requested list of package versions.final StringHow to sort the requested list of package versions.final PackageVersionStatusstatus()A string that filters the requested package versions by status.final StringA string that filters the requested package versions by status.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain that contains the repository that contains the requested package versions.
- Returns:
- The name of the domain that contains the repository that contains the requested package versions.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
repository
The name of the repository that contains the requested package versions.
- Returns:
- The name of the repository that contains the requested package versions.
-
format
The format of the package versions you want to list.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- The format of the package versions you want to list.
- See Also:
-
formatAsString
The format of the package versions you want to list.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- The format of the package versions you want to list.
- See Also:
-
namespace
The namespace of the package that contains the requested package versions. The package component that specifies its namespace depends on its type. For example:
The namespace is required when deleting package versions of the following formats:
-
Maven
-
Swift
-
generic
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
- Returns:
- The namespace of the package that contains the requested package versions. The package component that
specifies its namespace depends on its type. For example:
The namespace is required when deleting package versions of the following formats:
-
Maven
-
Swift
-
generic
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
-
-
-
packageValue
The name of the package for which you want to request package versions.
- Returns:
- The name of the package for which you want to request package versions.
-
status
A string that filters the requested package versions by status.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnPackageVersionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- A string that filters the requested package versions by status.
- See Also:
-
statusAsString
A string that filters the requested package versions by status.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnPackageVersionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- A string that filters the requested package versions by status.
- See Also:
-
sortBy
How to sort the requested list of package versions.
If the service returns an enum value that is not available in the current SDK version,
sortBywill returnPackageVersionSortType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsortByAsString().- Returns:
- How to sort the requested list of package versions.
- See Also:
-
sortByAsString
How to sort the requested list of package versions.
If the service returns an enum value that is not available in the current SDK version,
sortBywill returnPackageVersionSortType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromsortByAsString().- Returns:
- How to sort the requested list of package versions.
- See Also:
-
maxResults
The maximum number of results to return per page.
- Returns:
- The maximum number of results to return per page.
-
nextToken
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
- Returns:
- The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
-
originType
The
originTypeused to filter package versions. Only package versions with the providedoriginTypewill be returned.If the service returns an enum value that is not available in the current SDK version,
originTypewill returnPackageVersionOriginType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromoriginTypeAsString().- Returns:
- The
originTypeused to filter package versions. Only package versions with the providedoriginTypewill be returned. - See Also:
-
originTypeAsString
The
originTypeused to filter package versions. Only package versions with the providedoriginTypewill be returned.If the service returns an enum value that is not available in the current SDK version,
originTypewill returnPackageVersionOriginType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromoriginTypeAsString().- Returns:
- The
originTypeused to filter package versions. Only package versions with the providedoriginTypewill be returned. - See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListPackageVersionsRequest.Builder,ListPackageVersionsRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-