Class ListRepositoriesInDomainRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<ListRepositoriesInDomainRequest.Builder,ListRepositoriesInDomainRequest>

@Generated("software.amazon.awssdk:codegen") public final class ListRepositoriesInDomainRequest extends CodeartifactRequest implements ToCopyableBuilder<ListRepositoriesInDomainRequest.Builder,ListRepositoriesInDomainRequest>
  • Method Details

    • domain

      public final String domain()

      The name of the domain that contains the returned list of repositories.

      Returns:
      The name of the domain that contains the returned list of repositories.
    • domainOwner

      public final String domainOwner()

      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

      Returns:
      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
    • administratorAccount

      public final String administratorAccount()

      Filter the list of repositories to only include those that are managed by the Amazon Web Services account ID.

      Returns:
      Filter the list of repositories to only include those that are managed by the Amazon Web Services account ID.
    • repositoryPrefix

      public final String repositoryPrefix()

      A prefix used to filter returned repositories. Only repositories with names that start with repositoryPrefix are returned.

      Returns:
      A prefix used to filter returned repositories. Only repositories with names that start with repositoryPrefix are returned.
    • maxResults

      public final Integer maxResults()

      The maximum number of results to return per page.

      Returns:
      The maximum number of results to return per page.
    • nextToken

      public final String nextToken()

      The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

      Returns:
      The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<ListRepositoriesInDomainRequest.Builder,ListRepositoriesInDomainRequest>
      Specified by:
      toBuilder in class CodeartifactRequest
    • builder

      public static ListRepositoriesInDomainRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends ListRepositoriesInDomainRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo