Class PackageDescription
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<PackageDescription.Builder,PackageDescription>
Details about a package.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic PackageDescription.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final PackageFormatformat()A format that specifies the type of the package.final StringA format that specifies the type of the package.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name of the package.final StringThe namespace of the package.The package origin configuration for the package.static Class<? extends PackageDescription.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
format
A format that specifies the type of the package.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- A format that specifies the type of the package.
- See Also:
-
formatAsString
A format that specifies the type of the package.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- A format that specifies the type of the package.
- See Also:
-
namespace
The namespace of the package. The package component that specifies its namespace depends on its type. For example:
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
- Returns:
- The namespace of the package. The package component that specifies its namespace depends on its type. For
example:
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
-
-
-
name
The name of the package.
- Returns:
- The name of the package.
-
originConfiguration
The package origin configuration for the package.
- Returns:
- The package origin configuration for the package.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PackageDescription.Builder,PackageDescription>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-