Class PackageGroupAllowedRepository
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<PackageGroupAllowedRepository.Builder,PackageGroupAllowedRepository>
Details about an allowed repository for a package group, including its name and origin configuration.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()The origin configuration restriction type of the allowed repository.final StringThe origin configuration restriction type of the allowed repository.final StringThe name of the allowed repository.static Class<? extends PackageGroupAllowedRepository.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
repositoryName
The name of the allowed repository.
- Returns:
- The name of the allowed repository.
-
originRestrictionType
The origin configuration restriction type of the allowed repository.
If the service returns an enum value that is not available in the current SDK version,
originRestrictionTypewill returnPackageGroupOriginRestrictionType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromoriginRestrictionTypeAsString().- Returns:
- The origin configuration restriction type of the allowed repository.
- See Also:
-
originRestrictionTypeAsString
The origin configuration restriction type of the allowed repository.
If the service returns an enum value that is not available in the current SDK version,
originRestrictionTypewill returnPackageGroupOriginRestrictionType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromoriginRestrictionTypeAsString().- Returns:
- The origin configuration restriction type of the allowed repository.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PackageGroupAllowedRepository.Builder,PackageGroupAllowedRepository>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-