Class PackageGroupDescription
java.lang.Object
software.amazon.awssdk.services.codeartifact.model.PackageGroupDescription
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<PackageGroupDescription.Builder,PackageGroupDescription>
@Generated("software.amazon.awssdk:codegen")
public final class PackageGroupDescription
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<PackageGroupDescription.Builder,PackageGroupDescription>
The description of the package group.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Stringarn()The ARN of the package group.builder()final StringThe contact information of the package group.final InstantA timestamp that represents the date and time the package group was created.final StringThe description of the package group.final StringThe name of the domain that contains the package group.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()The package group origin configuration that determines how package versions can enter repositories.final PackageGroupReferenceparent()The direct parent package group of the package group.final Stringpattern()The pattern of the package group.static Class<? extends PackageGroupDescription.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
arn
The ARN of the package group.
- Returns:
- The ARN of the package group.
-
pattern
The pattern of the package group. The pattern determines which packages are associated with the package group.
- Returns:
- The pattern of the package group. The pattern determines which packages are associated with the package group.
-
domainName
The name of the domain that contains the package group.
- Returns:
- The name of the domain that contains the package group.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
createdTime
A timestamp that represents the date and time the package group was created.
- Returns:
- A timestamp that represents the date and time the package group was created.
-
contactInfo
The contact information of the package group.
- Returns:
- The contact information of the package group.
-
description
The description of the package group.
- Returns:
- The description of the package group.
-
originConfiguration
The package group origin configuration that determines how package versions can enter repositories.
- Returns:
- The package group origin configuration that determines how package versions can enter repositories.
-
parent
The direct parent package group of the package group.
- Returns:
- The direct parent package group of the package group.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PackageGroupDescription.Builder,PackageGroupDescription>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-