Class PackageGroupOriginRestriction
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<PackageGroupOriginRestriction.Builder,PackageGroupOriginRestriction>
Contains information about the configured restrictions of the origin controls of a package group.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()The effective package group origin restriction setting.final StringThe effective package group origin restriction setting.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final PackageGroupReferenceThe parent package group that the package group origin restrictions are inherited from.mode()The package group origin restriction setting.final StringThe package group origin restriction setting.final LongThe number of repositories in the allowed repository list.static Class<? extends PackageGroupOriginRestriction.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
mode
The package group origin restriction setting. If the value of
modeisALLOW,ALLOW_SPECIFIC_REPOSITORIES, orBLOCK, then the value ofeffectiveModeis the same. Otherwise, when the value isINHERIT, then the value ofeffectiveModeis the value ofmodeof the first parent group which does not have a value ofINHERIT.If the service returns an enum value that is not available in the current SDK version,
modewill returnPackageGroupOriginRestrictionMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frommodeAsString().- Returns:
- The package group origin restriction setting. If the value of
modeisALLOW,ALLOW_SPECIFIC_REPOSITORIES, orBLOCK, then the value ofeffectiveModeis the same. Otherwise, when the value isINHERIT, then the value ofeffectiveModeis the value ofmodeof the first parent group which does not have a value ofINHERIT. - See Also:
-
modeAsString
The package group origin restriction setting. If the value of
modeisALLOW,ALLOW_SPECIFIC_REPOSITORIES, orBLOCK, then the value ofeffectiveModeis the same. Otherwise, when the value isINHERIT, then the value ofeffectiveModeis the value ofmodeof the first parent group which does not have a value ofINHERIT.If the service returns an enum value that is not available in the current SDK version,
modewill returnPackageGroupOriginRestrictionMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frommodeAsString().- Returns:
- The package group origin restriction setting. If the value of
modeisALLOW,ALLOW_SPECIFIC_REPOSITORIES, orBLOCK, then the value ofeffectiveModeis the same. Otherwise, when the value isINHERIT, then the value ofeffectiveModeis the value ofmodeof the first parent group which does not have a value ofINHERIT. - See Also:
-
effectiveMode
The effective package group origin restriction setting. If the value of
modeisALLOW,ALLOW_SPECIFIC_REPOSITORIES, orBLOCK, then the value ofeffectiveModeis the same. Otherwise, when the value ofmodeisINHERIT, then the value ofeffectiveModeis the value ofmodeof the first parent group which does not have a value ofINHERIT.If the service returns an enum value that is not available in the current SDK version,
effectiveModewill returnPackageGroupOriginRestrictionMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromeffectiveModeAsString().- Returns:
- The effective package group origin restriction setting. If the value of
modeisALLOW,ALLOW_SPECIFIC_REPOSITORIES, orBLOCK, then the value ofeffectiveModeis the same. Otherwise, when the value ofmodeisINHERIT, then the value ofeffectiveModeis the value ofmodeof the first parent group which does not have a value ofINHERIT. - See Also:
-
effectiveModeAsString
The effective package group origin restriction setting. If the value of
modeisALLOW,ALLOW_SPECIFIC_REPOSITORIES, orBLOCK, then the value ofeffectiveModeis the same. Otherwise, when the value ofmodeisINHERIT, then the value ofeffectiveModeis the value ofmodeof the first parent group which does not have a value ofINHERIT.If the service returns an enum value that is not available in the current SDK version,
effectiveModewill returnPackageGroupOriginRestrictionMode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromeffectiveModeAsString().- Returns:
- The effective package group origin restriction setting. If the value of
modeisALLOW,ALLOW_SPECIFIC_REPOSITORIES, orBLOCK, then the value ofeffectiveModeis the same. Otherwise, when the value ofmodeisINHERIT, then the value ofeffectiveModeis the value ofmodeof the first parent group which does not have a value ofINHERIT. - See Also:
-
inheritedFrom
The parent package group that the package group origin restrictions are inherited from.
- Returns:
- The parent package group that the package group origin restrictions are inherited from.
-
repositoriesCount
The number of repositories in the allowed repository list.
- Returns:
- The number of repositories in the allowed repository list.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PackageGroupOriginRestriction.Builder,PackageGroupOriginRestriction>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-