Class PackageGroupReference
java.lang.Object
software.amazon.awssdk.services.codeartifact.model.PackageGroupReference
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<PackageGroupReference.Builder,PackageGroupReference>
@Generated("software.amazon.awssdk:codegen")
public final class PackageGroupReference
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<PackageGroupReference.Builder,PackageGroupReference>
Information about the identifiers of a package group.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Stringarn()The ARN of the package group.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringpattern()The pattern of the package group.static Class<? extends PackageGroupReference.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
arn
The ARN of the package group.
- Returns:
- The ARN of the package group.
-
pattern
The pattern of the package group. The pattern determines which packages are associated with the package group, and is also the identifier of the package group.
- Returns:
- The pattern of the package group. The pattern determines which packages are associated with the package group, and is also the identifier of the package group.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PackageGroupReference.Builder,PackageGroupReference>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-