Class PackageVersionError
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<PackageVersionError.Builder,PackageVersionError>
l An error associated with package.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic PackageVersionError.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final PackageVersionErrorCodeThe error code associated with the error.final StringThe error code associated with the error.final StringThe error message associated with the error.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends PackageVersionError.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
errorCode
The error code associated with the error. Valid error codes are:
-
ALREADY_EXISTS -
MISMATCHED_REVISION -
MISMATCHED_STATUS -
NOT_ALLOWED -
NOT_FOUND -
SKIPPED
If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnPackageVersionErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- The error code associated with the error. Valid error codes are:
-
ALREADY_EXISTS -
MISMATCHED_REVISION -
MISMATCHED_STATUS -
NOT_ALLOWED -
NOT_FOUND -
SKIPPED
-
- See Also:
-
-
errorCodeAsString
The error code associated with the error. Valid error codes are:
-
ALREADY_EXISTS -
MISMATCHED_REVISION -
MISMATCHED_STATUS -
NOT_ALLOWED -
NOT_FOUND -
SKIPPED
If the service returns an enum value that is not available in the current SDK version,
errorCodewill returnPackageVersionErrorCode.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromerrorCodeAsString().- Returns:
- The error code associated with the error. Valid error codes are:
-
ALREADY_EXISTS -
MISMATCHED_REVISION -
MISMATCHED_STATUS -
NOT_ALLOWED -
NOT_FOUND -
SKIPPED
-
- See Also:
-
-
errorMessage
The error message associated with the error.
- Returns:
- The error message associated with the error.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PackageVersionError.Builder,PackageVersionError>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-