Class PackageVersionOrigin
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<PackageVersionOrigin.Builder,PackageVersionOrigin>
Information about how a package version was added to a repository.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic PackageVersionOrigin.Builderbuilder()final DomainEntryPointA DomainEntryPoint object that contains information about from which repository or external connection the package version was added to the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final PackageVersionOriginTypeDescribes how the package version was originally added to the domain.final StringDescribes how the package version was originally added to the domain.static Class<? extends PackageVersionOrigin.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domainEntryPoint
A DomainEntryPoint object that contains information about from which repository or external connection the package version was added to the domain.
- Returns:
- A DomainEntryPoint object that contains information about from which repository or external connection the package version was added to the domain.
-
originType
Describes how the package version was originally added to the domain. An
INTERNALorigin type means the package version was published directly to a repository in the domain. AnEXTERNALorigin type means the package version was ingested from an external connection.If the service returns an enum value that is not available in the current SDK version,
originTypewill returnPackageVersionOriginType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromoriginTypeAsString().- Returns:
- Describes how the package version was originally added to the domain. An
INTERNALorigin type means the package version was published directly to a repository in the domain. AnEXTERNALorigin type means the package version was ingested from an external connection. - See Also:
-
originTypeAsString
Describes how the package version was originally added to the domain. An
INTERNALorigin type means the package version was published directly to a repository in the domain. AnEXTERNALorigin type means the package version was ingested from an external connection.If the service returns an enum value that is not available in the current SDK version,
originTypewill returnPackageVersionOriginType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromoriginTypeAsString().- Returns:
- Describes how the package version was originally added to the domain. An
INTERNALorigin type means the package version was published directly to a repository in the domain. AnEXTERNALorigin type means the package version was ingested from an external connection. - See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PackageVersionOrigin.Builder,PackageVersionOrigin>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-