Class PackageVersionSummary
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<PackageVersionSummary.Builder,PackageVersionSummary>
Details about a package version, including its status, version, and revision. The ListPackageVersions operation returns a list of PackageVersionSummary objects.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final PackageVersionOriginorigin()A PackageVersionOrigin object that contains information about how the package version was added to the repository.final Stringrevision()The revision associated with a package version.static Class<? extends PackageVersionSummary.Builder>final PackageVersionStatusstatus()A string that contains the status of the package version.final StringA string that contains the status of the package version.final StringtoString()Returns a string representation of this object.final Stringversion()Information about a package version.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
version
Information about a package version.
- Returns:
- Information about a package version.
-
revision
The revision associated with a package version.
- Returns:
- The revision associated with a package version.
-
status
A string that contains the status of the package version. It can be one of the following:
If the service returns an enum value that is not available in the current SDK version,
statuswill returnPackageVersionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- A string that contains the status of the package version. It can be one of the following:
- See Also:
-
statusAsString
A string that contains the status of the package version. It can be one of the following:
If the service returns an enum value that is not available in the current SDK version,
statuswill returnPackageVersionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- A string that contains the status of the package version. It can be one of the following:
- See Also:
-
origin
A PackageVersionOrigin object that contains information about how the package version was added to the repository.
- Returns:
- A PackageVersionOrigin object that contains information about how the package version was added to the repository.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PackageVersionSummary.Builder,PackageVersionSummary>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-