Class PublishPackageVersionResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PublishPackageVersionResponse.Builder,PublishPackageVersionResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal AssetSummaryasset()An AssetSummary for the published asset.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final PackageFormatformat()The format of the package version.final StringThe format of the package version.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe namespace of the package version.final StringThe name of the package.static Class<? extends PublishPackageVersionResponse.Builder>final PackageVersionStatusstatus()A string that contains the status of the package version.final StringA string that contains the status of the package version.final StringtoString()Returns a string representation of this object.final Stringversion()The version of the package.final StringThe revision of the package version.Methods inherited from class software.amazon.awssdk.services.codeartifact.model.CodeartifactResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
format
The format of the package version.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- The format of the package version.
- See Also:
-
formatAsString
The format of the package version.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- The format of the package version.
- See Also:
-
namespace
The namespace of the package version.
- Returns:
- The namespace of the package version.
-
packageValue
The name of the package.
- Returns:
- The name of the package.
-
version
The version of the package.
- Returns:
- The version of the package.
-
versionRevision
The revision of the package version.
- Returns:
- The revision of the package version.
-
status
A string that contains the status of the package version. For more information, see Package version status in the CodeArtifact User Guide.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnPackageVersionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- A string that contains the status of the package version. For more information, see Package version status in the CodeArtifact User Guide.
- See Also:
-
statusAsString
A string that contains the status of the package version. For more information, see Package version status in the CodeArtifact User Guide.
If the service returns an enum value that is not available in the current SDK version,
statuswill returnPackageVersionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- A string that contains the status of the package version. For more information, see Package version status in the CodeArtifact User Guide.
- See Also:
-
asset
An AssetSummary for the published asset.
- Returns:
- An AssetSummary for the published asset.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PublishPackageVersionResponse.Builder,PublishPackageVersionResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-