Class PutPackageOriginConfigurationRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PutPackageOriginConfigurationRequest.Builder,PutPackageOriginConfigurationRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringdomain()The name of the domain that contains the repository that contains the package.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final PackageFormatformat()A format that specifies the type of the package to be updated.final StringA format that specifies the type of the package to be updated.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe namespace of the package to be updated.final StringThe name of the package to be updated.final StringThe name of the repository that contains the package.A PackageOriginRestrictions object that contains information about theupstreamandpublishpackage origin restrictions.static Class<? extends PutPackageOriginConfigurationRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain that contains the repository that contains the package.
- Returns:
- The name of the domain that contains the repository that contains the package.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
repository
The name of the repository that contains the package.
- Returns:
- The name of the repository that contains the package.
-
format
A format that specifies the type of the package to be updated.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- A format that specifies the type of the package to be updated.
- See Also:
-
formatAsString
A format that specifies the type of the package to be updated.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- A format that specifies the type of the package to be updated.
- See Also:
-
namespace
The namespace of the package to be updated. The package component that specifies its namespace depends on its type. For example:
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
- Returns:
- The namespace of the package to be updated. The package component that specifies its namespace depends on
its type. For example:
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
-
-
-
packageValue
The name of the package to be updated.
- Returns:
- The name of the package to be updated.
-
restrictions
A PackageOriginRestrictions object that contains information about the
upstreamandpublishpackage origin restrictions. Theupstreamrestriction determines if new package versions can be ingested or retained from external connections or upstream repositories. Thepublishrestriction determines if new package versions can be published directly to the repository.You must include both the desired
upstreamandpublishrestrictions.- Returns:
- A PackageOriginRestrictions object that contains information about the
upstreamandpublishpackage origin restrictions. Theupstreamrestriction determines if new package versions can be ingested or retained from external connections or upstream repositories. Thepublishrestriction determines if new package versions can be published directly to the repository.You must include both the desired
upstreamandpublishrestrictions.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PutPackageOriginConfigurationRequest.Builder,PutPackageOriginConfigurationRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
public static Class<? extends PutPackageOriginConfigurationRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-