Class PutRepositoryPermissionsPolicyRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<PutRepositoryPermissionsPolicyRequest.Builder,PutRepositoryPermissionsPolicyRequest>

@Generated("software.amazon.awssdk:codegen") public final class PutRepositoryPermissionsPolicyRequest extends CodeartifactRequest implements ToCopyableBuilder<PutRepositoryPermissionsPolicyRequest.Builder,PutRepositoryPermissionsPolicyRequest>
  • Method Details

    • domain

      public final String domain()

      The name of the domain containing the repository to set the resource policy on.

      Returns:
      The name of the domain containing the repository to set the resource policy on.
    • domainOwner

      public final String domainOwner()

      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

      Returns:
      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
    • repository

      public final String repository()

      The name of the repository to set the resource policy on.

      Returns:
      The name of the repository to set the resource policy on.
    • policyRevision

      public final String policyRevision()

      Sets the revision of the resource policy that specifies permissions to access the repository. This revision is used for optimistic locking, which prevents others from overwriting your changes to the repository's resource policy.

      Returns:
      Sets the revision of the resource policy that specifies permissions to access the repository. This revision is used for optimistic locking, which prevents others from overwriting your changes to the repository's resource policy.
    • policyDocument

      public final String policyDocument()

      A valid displayable JSON Aspen policy string to be set as the access control resource policy on the provided repository.

      Returns:
      A valid displayable JSON Aspen policy string to be set as the access control resource policy on the provided repository.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<PutRepositoryPermissionsPolicyRequest.Builder,PutRepositoryPermissionsPolicyRequest>
      Specified by:
      toBuilder in class CodeartifactRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends PutRepositoryPermissionsPolicyRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo