Interface PutRepositoryPermissionsPolicyRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CodeartifactRequest.Builder,CopyableBuilder<PutRepositoryPermissionsPolicyRequest.Builder,,PutRepositoryPermissionsPolicyRequest> SdkBuilder<PutRepositoryPermissionsPolicyRequest.Builder,,PutRepositoryPermissionsPolicyRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- PutRepositoryPermissionsPolicyRequest
@Mutable
@NotThreadSafe
public static interface PutRepositoryPermissionsPolicyRequest.Builder
extends CodeartifactRequest.Builder, SdkPojo, CopyableBuilder<PutRepositoryPermissionsPolicyRequest.Builder,PutRepositoryPermissionsPolicyRequest>
-
Method Summary
Modifier and TypeMethodDescriptionThe name of the domain containing the repository to set the resource policy on.domainOwner(String domainOwner) The 12-digit account number of the Amazon Web Services account that owns the domain.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) policyDocument(String policyDocument) A valid displayable JSON Aspen policy string to be set as the access control resource policy on the provided repository.policyRevision(String policyRevision) Sets the revision of the resource policy that specifies permissions to access the repository.repository(String repository) The name of the repository to set the resource policy on.Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
domain
The name of the domain containing the repository to set the resource policy on.
- Parameters:
domain- The name of the domain containing the repository to set the resource policy on.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Parameters:
domainOwner- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
repository
The name of the repository to set the resource policy on.
- Parameters:
repository- The name of the repository to set the resource policy on.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
policyRevision
Sets the revision of the resource policy that specifies permissions to access the repository. This revision is used for optimistic locking, which prevents others from overwriting your changes to the repository's resource policy.
- Parameters:
policyRevision- Sets the revision of the resource policy that specifies permissions to access the repository. This revision is used for optimistic locking, which prevents others from overwriting your changes to the repository's resource policy.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
policyDocument
A valid displayable JSON Aspen policy string to be set as the access control resource policy on the provided repository.
- Parameters:
policyDocument- A valid displayable JSON Aspen policy string to be set as the access control resource policy on the provided repository.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
PutRepositoryPermissionsPolicyRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
PutRepositoryPermissionsPolicyRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-