Class RepositoryDescription
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<RepositoryDescription.Builder,RepositoryDescription>
The details of a repository stored in CodeArtifact. A CodeArtifact repository contains a set of package versions,
each of which maps to a set of assets. Repositories are polyglotâa single repository can contain packages of any
supported type. Each repository exposes endpoints for fetching and publishing packages using tools like the
npm CLI, the Maven CLI (mvn), and pip. You can create up to 100 repositories
per Amazon Web Services account.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe 12-digit account number of the Amazon Web Services account that manages the repository.final Stringarn()The Amazon Resource Name (ARN) of the repository.builder()final InstantA timestamp that represents the date and time the repository was created.final StringA text description of the repository.final StringThe name of the domain that contains the repository.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain that contains the repository.final booleanfinal booleanequalsBySdkFields(Object obj) An array of external connections associated with the repository.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the ExternalConnections property.final inthashCode()final booleanFor responses, this returns true if the service returned a value for the Upstreams property.final Stringname()The name of the repository.static Class<? extends RepositoryDescription.Builder>final StringtoString()Returns a string representation of this object.final List<UpstreamRepositoryInfo>A list of upstream repositories to associate with the repository.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the repository.
- Returns:
- The name of the repository.
-
administratorAccount
The 12-digit account number of the Amazon Web Services account that manages the repository.
- Returns:
- The 12-digit account number of the Amazon Web Services account that manages the repository.
-
domainName
The name of the domain that contains the repository.
- Returns:
- The name of the domain that contains the repository.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain that contains the repository. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain that contains the repository. It does not include dashes or spaces.
-
arn
The Amazon Resource Name (ARN) of the repository.
- Returns:
- The Amazon Resource Name (ARN) of the repository.
-
description
A text description of the repository.
- Returns:
- A text description of the repository.
-
hasUpstreams
public final boolean hasUpstreams()For responses, this returns true if the service returned a value for the Upstreams property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
upstreams
A list of upstream repositories to associate with the repository. The order of the upstream repositories in the list determines their priority order when CodeArtifact looks for a requested package version. For more information, see Working with upstream repositories.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasUpstreams()method.- Returns:
- A list of upstream repositories to associate with the repository. The order of the upstream repositories in the list determines their priority order when CodeArtifact looks for a requested package version. For more information, see Working with upstream repositories.
-
hasExternalConnections
public final boolean hasExternalConnections()For responses, this returns true if the service returned a value for the ExternalConnections property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
externalConnections
An array of external connections associated with the repository.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasExternalConnections()method.- Returns:
- An array of external connections associated with the repository.
-
createdTime
A timestamp that represents the date and time the repository was created.
- Returns:
- A timestamp that represents the date and time the repository was created.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<RepositoryDescription.Builder,RepositoryDescription>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-