Class RepositoryExternalConnectionInfo
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<RepositoryExternalConnectionInfo.Builder,RepositoryExternalConnectionInfo>
Contains information about the external connection of a repository.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name of the external connection associated with a repository.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final PackageFormatThe package format associated with a repository's external connection.final StringThe package format associated with a repository's external connection.static Class<? extends RepositoryExternalConnectionInfo.Builder>final ExternalConnectionStatusstatus()The status of the external connection of a repository.final StringThe status of the external connection of a repository.final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
externalConnectionName
The name of the external connection associated with a repository.
- Returns:
- The name of the external connection associated with a repository.
-
packageFormat
The package format associated with a repository's external connection. The valid package formats are:
-
npm: A Node Package Manager (npm) package. -
pypi: A Python Package Index (PyPI) package. -
maven: A Maven package that contains compiled code in a distributable format, such as a JAR file. -
nuget: A NuGet package. -
generic: A generic package. -
ruby: A Ruby package. -
swift: A Swift package. -
cargo: A Cargo package.
If the service returns an enum value that is not available in the current SDK version,
packageFormatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frompackageFormatAsString().- Returns:
- The package format associated with a repository's external connection. The valid package formats are:
-
npm: A Node Package Manager (npm) package. -
pypi: A Python Package Index (PyPI) package. -
maven: A Maven package that contains compiled code in a distributable format, such as a JAR file. -
nuget: A NuGet package. -
generic: A generic package. -
ruby: A Ruby package. -
swift: A Swift package. -
cargo: A Cargo package.
-
- See Also:
-
-
packageFormatAsString
The package format associated with a repository's external connection. The valid package formats are:
-
npm: A Node Package Manager (npm) package. -
pypi: A Python Package Index (PyPI) package. -
maven: A Maven package that contains compiled code in a distributable format, such as a JAR file. -
nuget: A NuGet package. -
generic: A generic package. -
ruby: A Ruby package. -
swift: A Swift package. -
cargo: A Cargo package.
If the service returns an enum value that is not available in the current SDK version,
packageFormatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frompackageFormatAsString().- Returns:
- The package format associated with a repository's external connection. The valid package formats are:
-
npm: A Node Package Manager (npm) package. -
pypi: A Python Package Index (PyPI) package. -
maven: A Maven package that contains compiled code in a distributable format, such as a JAR file. -
nuget: A NuGet package. -
generic: A generic package. -
ruby: A Ruby package. -
swift: A Swift package. -
cargo: A Cargo package.
-
- See Also:
-
-
status
The status of the external connection of a repository. There is one valid value,
Available.If the service returns an enum value that is not available in the current SDK version,
statuswill returnExternalConnectionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The status of the external connection of a repository. There is one valid value,
Available. - See Also:
-
statusAsString
The status of the external connection of a repository. There is one valid value,
Available.If the service returns an enum value that is not available in the current SDK version,
statuswill returnExternalConnectionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromstatusAsString().- Returns:
- The status of the external connection of a repository. There is one valid value,
Available. - See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<RepositoryExternalConnectionInfo.Builder,RepositoryExternalConnectionInfo>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-