Class RepositorySummary
java.lang.Object
software.amazon.awssdk.services.codeartifact.model.RepositorySummary
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<RepositorySummary.Builder,RepositorySummary>
@Generated("software.amazon.awssdk:codegen")
public final class RepositorySummary
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<RepositorySummary.Builder,RepositorySummary>
Details about a repository, including its Amazon Resource Name (ARN), description, and domain information. The ListRepositories
operation returns a list of RepositorySummary objects.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe Amazon Web Services account ID that manages the repository.final Stringarn()The ARN of the repository.static RepositorySummary.Builderbuilder()final InstantA timestamp that represents the date and time the repository was created.final StringThe description of the repository.final StringThe name of the domain that contains the repository.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final Stringname()The name of the repository.static Class<? extends RepositorySummary.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
name
The name of the repository.
- Returns:
- The name of the repository.
-
administratorAccount
The Amazon Web Services account ID that manages the repository.
- Returns:
- The Amazon Web Services account ID that manages the repository.
-
domainName
The name of the domain that contains the repository.
- Returns:
- The name of the domain that contains the repository.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
arn
The ARN of the repository.
- Returns:
- The ARN of the repository.
-
description
The description of the repository.
- Returns:
- The description of the repository.
-
createdTime
A timestamp that represents the date and time the repository was created.
- Returns:
- A timestamp that represents the date and time the repository was created.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<RepositorySummary.Builder,RepositorySummary>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-