Interface ResourceNotFoundException.Builder
- All Superinterfaces:
AwsServiceException.Builder,Buildable,CodeartifactException.Builder,CopyableBuilder<ResourceNotFoundException.Builder,,ResourceNotFoundException> SdkBuilder<ResourceNotFoundException.Builder,,ResourceNotFoundException> SdkException.Builder,SdkPojo,SdkServiceException.Builder
- Enclosing class:
- ResourceNotFoundException
@Mutable
@NotThreadSafe
public static interface ResourceNotFoundException.Builder
extends SdkPojo, CopyableBuilder<ResourceNotFoundException.Builder,ResourceNotFoundException>, CodeartifactException.Builder
-
Method Summary
Modifier and TypeMethodDescriptionawsErrorDetails(AwsErrorDetails awsErrorDetails) numAttempts(Integer numAttempts) resourceId(String resourceId) The ID of the resource.resourceType(String resourceType) The type of Amazon Web Services resource.resourceType(ResourceType resourceType) The type of Amazon Web Services resource.statusCode(int statusCode) writableStackTrace(Boolean writableStackTrace) Methods inherited from interface software.amazon.awssdk.awscore.exception.AwsServiceException.Builder
awsErrorDetails, build, clockSkew, clockSkew, extendedRequestIdMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.exception.SdkException.Builder
cause, message, numAttempts, writableStackTraceMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFieldsMethods inherited from interface software.amazon.awssdk.core.exception.SdkServiceException.Builder
extendedRequestId, requestId, statusCode
-
Method Details
-
resourceId
The ID of the resource.
- Parameters:
resourceId- The ID of the resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
resourceType
The type of Amazon Web Services resource.
- Parameters:
resourceType- The type of Amazon Web Services resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
resourceType
The type of Amazon Web Services resource.
- Parameters:
resourceType- The type of Amazon Web Services resource.- Returns:
- Returns a reference to this object so that method calls can be chained together.
- See Also:
-
awsErrorDetails
- Specified by:
awsErrorDetailsin interfaceAwsServiceException.Builder- Specified by:
awsErrorDetailsin interfaceCodeartifactException.Builder
-
message
- Specified by:
messagein interfaceAwsServiceException.Builder- Specified by:
messagein interfaceCodeartifactException.Builder- Specified by:
messagein interfaceSdkException.Builder- Specified by:
messagein interfaceSdkServiceException.Builder
-
requestId
- Specified by:
requestIdin interfaceAwsServiceException.Builder- Specified by:
requestIdin interfaceCodeartifactException.Builder- Specified by:
requestIdin interfaceSdkServiceException.Builder
-
statusCode
- Specified by:
statusCodein interfaceAwsServiceException.Builder- Specified by:
statusCodein interfaceCodeartifactException.Builder- Specified by:
statusCodein interfaceSdkServiceException.Builder
-
cause
- Specified by:
causein interfaceAwsServiceException.Builder- Specified by:
causein interfaceCodeartifactException.Builder- Specified by:
causein interfaceSdkException.Builder- Specified by:
causein interfaceSdkServiceException.Builder
-
writableStackTrace
- Specified by:
writableStackTracein interfaceCodeartifactException.Builder- Specified by:
writableStackTracein interfaceSdkException.Builder- Specified by:
writableStackTracein interfaceSdkServiceException.Builder
-
numAttempts
- Specified by:
numAttemptsin interfaceAwsServiceException.Builder- Specified by:
numAttemptsin interfaceCodeartifactException.Builder- Specified by:
numAttemptsin interfaceSdkException.Builder- Specified by:
numAttemptsin interfaceSdkServiceException.Builder
-