Class ResourcePolicy
java.lang.Object
software.amazon.awssdk.services.codeartifact.model.ResourcePolicy
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<ResourcePolicy.Builder,ResourcePolicy>
@Generated("software.amazon.awssdk:codegen")
public final class ResourcePolicy
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<ResourcePolicy.Builder,ResourcePolicy>
An CodeArtifact resource policy that contains a resource ARN, document details, and a revision.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic ResourcePolicy.Builderbuilder()final Stringdocument()The resource policy formatted in JSON.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe ARN of the resource associated with the resource policyfinal Stringrevision()The current revision of the resource policy.static Class<? extends ResourcePolicy.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
resourceArn
The ARN of the resource associated with the resource policy
- Returns:
- The ARN of the resource associated with the resource policy
-
revision
The current revision of the resource policy.
- Returns:
- The current revision of the resource policy.
-
document
The resource policy formatted in JSON.
- Returns:
- The resource policy formatted in JSON.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ResourcePolicy.Builder,ResourcePolicy>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-