Class UpdatePackageGroupOriginConfigurationRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<UpdatePackageGroupOriginConfigurationRequest.Builder,UpdatePackageGroupOriginConfigurationRequest>

@Generated("software.amazon.awssdk:codegen") public final class UpdatePackageGroupOriginConfigurationRequest extends CodeartifactRequest implements ToCopyableBuilder<UpdatePackageGroupOriginConfigurationRequest.Builder,UpdatePackageGroupOriginConfigurationRequest>
  • Method Details

    • domain

      public final String domain()

      The name of the domain which contains the package group for which to update the origin configuration.

      Returns:
      The name of the domain which contains the package group for which to update the origin configuration.
    • domainOwner

      public final String domainOwner()

      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

      Returns:
      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
    • packageGroup

      public final String packageGroup()

      The pattern of the package group for which to update the origin configuration.

      Returns:
      The pattern of the package group for which to update the origin configuration.
    • restrictions

      The origin configuration settings that determine how package versions can enter repositories.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasRestrictions() method.

      Returns:
      The origin configuration settings that determine how package versions can enter repositories.
    • hasRestrictions

      public final boolean hasRestrictions()
      For responses, this returns true if the service returned a value for the Restrictions property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • restrictionsAsStrings

      public final Map<String,String> restrictionsAsStrings()

      The origin configuration settings that determine how package versions can enter repositories.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasRestrictions() method.

      Returns:
      The origin configuration settings that determine how package versions can enter repositories.
    • hasAddAllowedRepositories

      public final boolean hasAddAllowedRepositories()
      For responses, this returns true if the service returned a value for the AddAllowedRepositories property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • addAllowedRepositories

      public final List<PackageGroupAllowedRepository> addAllowedRepositories()

      The repository name and restrictions to add to the allowed repository list of the specified package group.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasAddAllowedRepositories() method.

      Returns:
      The repository name and restrictions to add to the allowed repository list of the specified package group.
    • hasRemoveAllowedRepositories

      public final boolean hasRemoveAllowedRepositories()
      For responses, this returns true if the service returned a value for the RemoveAllowedRepositories property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • removeAllowedRepositories

      public final List<PackageGroupAllowedRepository> removeAllowedRepositories()

      The repository name and restrictions to remove from the allowed repository list of the specified package group.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasRemoveAllowedRepositories() method.

      Returns:
      The repository name and restrictions to remove from the allowed repository list of the specified package group.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<UpdatePackageGroupOriginConfigurationRequest.Builder,UpdatePackageGroupOriginConfigurationRequest>
      Specified by:
      toBuilder in class CodeartifactRequest
    • builder

    • serializableBuilderClass

      public static Class<? extends UpdatePackageGroupOriginConfigurationRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo