Class UpdatePackageGroupRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<UpdatePackageGroupRequest.Builder,UpdatePackageGroupRequest>

@Generated("software.amazon.awssdk:codegen") public final class UpdatePackageGroupRequest extends CodeartifactRequest implements ToCopyableBuilder<UpdatePackageGroupRequest.Builder,UpdatePackageGroupRequest>
  • Method Details

    • domain

      public final String domain()

      The name of the domain which contains the package group to be updated.

      Returns:
      The name of the domain which contains the package group to be updated.
    • domainOwner

      public final String domainOwner()

      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.

      Returns:
      The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
    • packageGroup

      public final String packageGroup()

      The pattern of the package group to be updated.

      Returns:
      The pattern of the package group to be updated.
    • contactInfo

      public final String contactInfo()

      Contact information which you want to update the requested package group with.

      Returns:
      Contact information which you want to update the requested package group with.
    • description

      public final String description()

      The description you want to update the requested package group with.

      Returns:
      The description you want to update the requested package group with.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<UpdatePackageGroupRequest.Builder,UpdatePackageGroupRequest>
      Specified by:
      toBuilder in class CodeartifactRequest
    • builder

      public static UpdatePackageGroupRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends UpdatePackageGroupRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo