Class UpdatePackageVersionsStatusResponse

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<UpdatePackageVersionsStatusResponse.Builder,UpdatePackageVersionsStatusResponse>

@Generated("software.amazon.awssdk:codegen") public final class UpdatePackageVersionsStatusResponse extends CodeartifactResponse implements ToCopyableBuilder<UpdatePackageVersionsStatusResponse.Builder,UpdatePackageVersionsStatusResponse>
  • Method Details

    • hasSuccessfulVersions

      public final boolean hasSuccessfulVersions()
      For responses, this returns true if the service returned a value for the SuccessfulVersions property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • successfulVersions

      public final Map<String,SuccessfulPackageVersionInfo> successfulVersions()

      A list of PackageVersionError objects, one for each package version with a status that failed to update.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasSuccessfulVersions() method.

      Returns:
      A list of PackageVersionError objects, one for each package version with a status that failed to update.
    • hasFailedVersions

      public final boolean hasFailedVersions()
      For responses, this returns true if the service returned a value for the FailedVersions property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
    • failedVersions

      public final Map<String,PackageVersionError> failedVersions()

      A list of SuccessfulPackageVersionInfo objects, one for each package version with a status that successfully updated.

      Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

      This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasFailedVersions() method.

      Returns:
      A list of SuccessfulPackageVersionInfo objects, one for each package version with a status that successfully updated.
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<UpdatePackageVersionsStatusResponse.Builder,UpdatePackageVersionsStatusResponse>
      Specified by:
      toBuilder in class AwsResponse
    • builder

    • serializableBuilderClass

      public static Class<? extends UpdatePackageVersionsStatusResponse.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsResponse
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsResponse
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkResponse
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo