Uses of Interface
software.amazon.awssdk.services.codeartifact.model.AssociateExternalConnectionResponse.Builder
Packages that use AssociateExternalConnectionResponse.Builder
-
Uses of AssociateExternalConnectionResponse.Builder in software.amazon.awssdk.services.codeartifact.model
Methods in software.amazon.awssdk.services.codeartifact.model that return AssociateExternalConnectionResponse.BuilderModifier and TypeMethodDescriptionAssociateExternalConnectionResponse.builder()AssociateExternalConnectionResponse.Builder.repository(Consumer<RepositoryDescription.Builder> repository) Information about the connected repository after processing the request.AssociateExternalConnectionResponse.Builder.repository(RepositoryDescription repository) Information about the connected repository after processing the request.AssociateExternalConnectionResponse.toBuilder()Methods in software.amazon.awssdk.services.codeartifact.model that return types with arguments of type AssociateExternalConnectionResponse.BuilderModifier and TypeMethodDescriptionstatic Class<? extends AssociateExternalConnectionResponse.Builder>AssociateExternalConnectionResponse.serializableBuilderClass()