Uses of Class
software.amazon.awssdk.services.codeartifact.model.DescribeRepositoryRequest

Packages that use DescribeRepositoryRequest
Package
Description
CodeArtifact is a fully managed artifact repository compatible with language-native package managers and build tools such as npm, Apache Maven, pip, and dotnet.