Uses of Class
software.amazon.awssdk.services.codeartifact.model.DomainDescription
Packages that use DomainDescription
-
Uses of DomainDescription in software.amazon.awssdk.services.codeartifact.model
Methods in software.amazon.awssdk.services.codeartifact.model that return DomainDescriptionModifier and TypeMethodDescriptionfinal DomainDescriptionCreateDomainResponse.domain()Contains information about the created domain after processing the request.final DomainDescriptionDeleteDomainResponse.domain()Contains information about the deleted domain after processing the request.final DomainDescriptionDescribeDomainResponse.domain()Returns the value of the Domain property for this object.Methods in software.amazon.awssdk.services.codeartifact.model with parameters of type DomainDescriptionModifier and TypeMethodDescriptionCreateDomainResponse.Builder.domain(DomainDescription domain) Contains information about the created domain after processing the request.DeleteDomainResponse.Builder.domain(DomainDescription domain) Contains information about the deleted domain after processing the request.DescribeDomainResponse.Builder.domain(DomainDescription domain) Sets the value of the Domain property for this object.