Uses of Class
software.amazon.awssdk.services.codeartifact.model.DomainEntryPoint
Packages that use DomainEntryPoint
-
Uses of DomainEntryPoint in software.amazon.awssdk.services.codeartifact.model
Methods in software.amazon.awssdk.services.codeartifact.model that return DomainEntryPointModifier and TypeMethodDescriptionfinal DomainEntryPointPackageVersionOrigin.domainEntryPoint()A DomainEntryPoint object that contains information about from which repository or external connection the package version was added to the domain.Methods in software.amazon.awssdk.services.codeartifact.model with parameters of type DomainEntryPointModifier and TypeMethodDescriptionPackageVersionOrigin.Builder.domainEntryPoint(DomainEntryPoint domainEntryPoint) A DomainEntryPoint object that contains information about from which repository or external connection the package version was added to the domain.