Uses of Class
software.amazon.awssdk.services.codeartifact.model.GetRepositoryEndpointRequest
Packages that use GetRepositoryEndpointRequest
Package
Description
CodeArtifact is a fully managed artifact repository compatible with language-native package managers and build tools
such as npm, Apache Maven, pip, and dotnet.
-
Uses of GetRepositoryEndpointRequest in software.amazon.awssdk.services.codeartifact
Methods in software.amazon.awssdk.services.codeartifact with parameters of type GetRepositoryEndpointRequestModifier and TypeMethodDescriptionCodeartifactAsyncClient.getRepositoryEndpoint(GetRepositoryEndpointRequest getRepositoryEndpointRequest) Returns the endpoint of a repository for a specific package format.default GetRepositoryEndpointResponseCodeartifactClient.getRepositoryEndpoint(GetRepositoryEndpointRequest getRepositoryEndpointRequest) Returns the endpoint of a repository for a specific package format. -
Uses of GetRepositoryEndpointRequest in software.amazon.awssdk.services.codeartifact.transform
Methods in software.amazon.awssdk.services.codeartifact.transform with parameters of type GetRepositoryEndpointRequestModifier and TypeMethodDescriptionGetRepositoryEndpointRequestMarshaller.marshall(GetRepositoryEndpointRequest getRepositoryEndpointRequest)