Uses of Enum
software.amazon.awssdk.services.codeartifact.model.PackageGroupOriginRestrictionMode
Packages that use PackageGroupOriginRestrictionMode
-
Uses of PackageGroupOriginRestrictionMode in software.amazon.awssdk.services.codeartifact.model
Methods in software.amazon.awssdk.services.codeartifact.model that return PackageGroupOriginRestrictionModeModifier and TypeMethodDescriptionPackageGroupOriginRestriction.effectiveMode()The effective package group origin restriction setting.Use this in place of valueOf to convert the raw string returned by the service into the enum value.PackageGroupOriginRestriction.mode()The package group origin restriction setting.Returns the enum constant of this type with the specified name.static PackageGroupOriginRestrictionMode[]PackageGroupOriginRestrictionMode.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.codeartifact.model that return types with arguments of type PackageGroupOriginRestrictionModeModifier and TypeMethodDescriptionstatic Set<PackageGroupOriginRestrictionMode>PackageGroupOriginRestrictionMode.knownValues()UpdatePackageGroupOriginConfigurationRequest.restrictions()The origin configuration settings that determine how package versions can enter repositories.Methods in software.amazon.awssdk.services.codeartifact.model with parameters of type PackageGroupOriginRestrictionModeModifier and TypeMethodDescriptionPackageGroupOriginRestriction.Builder.effectiveMode(PackageGroupOriginRestrictionMode effectiveMode) The effective package group origin restriction setting.PackageGroupOriginRestriction.Builder.mode(PackageGroupOriginRestrictionMode mode) The package group origin restriction setting.Method parameters in software.amazon.awssdk.services.codeartifact.model with type arguments of type PackageGroupOriginRestrictionModeModifier and TypeMethodDescriptionUpdatePackageGroupOriginConfigurationRequest.Builder.restrictions(Map<PackageGroupOriginRestrictionType, PackageGroupOriginRestrictionMode> restrictions) The origin configuration settings that determine how package versions can enter repositories.