Uses of Enum
software.amazon.awssdk.services.codeartifact.model.PackageVersionErrorCode
Packages that use PackageVersionErrorCode
-
Uses of PackageVersionErrorCode in software.amazon.awssdk.services.codeartifact.model
Methods in software.amazon.awssdk.services.codeartifact.model that return PackageVersionErrorCodeModifier and TypeMethodDescriptionfinal PackageVersionErrorCodePackageVersionError.errorCode()The error code associated with the error.static PackageVersionErrorCodeUse this in place of valueOf to convert the raw string returned by the service into the enum value.static PackageVersionErrorCodeReturns the enum constant of this type with the specified name.static PackageVersionErrorCode[]PackageVersionErrorCode.values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in software.amazon.awssdk.services.codeartifact.model that return types with arguments of type PackageVersionErrorCodeModifier and TypeMethodDescriptionstatic Set<PackageVersionErrorCode>PackageVersionErrorCode.knownValues()Methods in software.amazon.awssdk.services.codeartifact.model with parameters of type PackageVersionErrorCodeModifier and TypeMethodDescriptionPackageVersionError.Builder.errorCode(PackageVersionErrorCode errorCode) The error code associated with the error.