Uses of Class
software.amazon.awssdk.services.codeartifact.model.RepositoryDescription
Packages that use RepositoryDescription
-
Uses of RepositoryDescription in software.amazon.awssdk.services.codeartifact.model
Methods in software.amazon.awssdk.services.codeartifact.model that return RepositoryDescriptionModifier and TypeMethodDescriptionfinal RepositoryDescriptionAssociateExternalConnectionResponse.repository()Information about the connected repository after processing the request.final RepositoryDescriptionCreateRepositoryResponse.repository()Information about the created repository after processing the request.final RepositoryDescriptionDeleteRepositoryResponse.repository()Information about the deleted repository after processing the request.final RepositoryDescriptionDescribeRepositoryResponse.repository()ARepositoryDescriptionobject that contains the requested repository information.final RepositoryDescriptionDisassociateExternalConnectionResponse.repository()The repository associated with the removed external connection.final RepositoryDescriptionUpdateRepositoryResponse.repository()The updated repository.Methods in software.amazon.awssdk.services.codeartifact.model with parameters of type RepositoryDescriptionModifier and TypeMethodDescriptionAssociateExternalConnectionResponse.Builder.repository(RepositoryDescription repository) Information about the connected repository after processing the request.CreateRepositoryResponse.Builder.repository(RepositoryDescription repository) Information about the created repository after processing the request.DeleteRepositoryResponse.Builder.repository(RepositoryDescription repository) Information about the deleted repository after processing the request.DescribeRepositoryResponse.Builder.repository(RepositoryDescription repository) ARepositoryDescriptionobject that contains the requested repository information.DisassociateExternalConnectionResponse.Builder.repository(RepositoryDescription repository) The repository associated with the removed external connection.UpdateRepositoryResponse.Builder.repository(RepositoryDescription repository) The updated repository.