Uses of Class
software.amazon.awssdk.services.codeartifact.model.RepositoryExternalConnectionInfo
Packages that use RepositoryExternalConnectionInfo
-
Uses of RepositoryExternalConnectionInfo in software.amazon.awssdk.services.codeartifact.model
Methods in software.amazon.awssdk.services.codeartifact.model that return types with arguments of type RepositoryExternalConnectionInfoModifier and TypeMethodDescriptionRepositoryDescription.externalConnections()An array of external connections associated with the repository.Methods in software.amazon.awssdk.services.codeartifact.model with parameters of type RepositoryExternalConnectionInfoModifier and TypeMethodDescriptionRepositoryDescription.Builder.externalConnections(RepositoryExternalConnectionInfo... externalConnections) An array of external connections associated with the repository.Method parameters in software.amazon.awssdk.services.codeartifact.model with type arguments of type RepositoryExternalConnectionInfoModifier and TypeMethodDescriptionRepositoryDescription.Builder.externalConnections(Collection<RepositoryExternalConnectionInfo> externalConnections) An array of external connections associated with the repository.