Uses of Class
software.amazon.awssdk.services.codeartifact.model.RepositorySummary
Packages that use RepositorySummary
Package
Description
-
Uses of RepositorySummary in software.amazon.awssdk.services.codeartifact.model
Methods in software.amazon.awssdk.services.codeartifact.model that return types with arguments of type RepositorySummaryModifier and TypeMethodDescriptionfinal List<RepositorySummary>ListRepositoriesInDomainResponse.repositories()The returned list of repositories.final List<RepositorySummary>ListRepositoriesResponse.repositories()The returned list of RepositorySummary objects.Methods in software.amazon.awssdk.services.codeartifact.model with parameters of type RepositorySummaryModifier and TypeMethodDescriptionListRepositoriesInDomainResponse.Builder.repositories(RepositorySummary... repositories) The returned list of repositories.ListRepositoriesResponse.Builder.repositories(RepositorySummary... repositories) The returned list of RepositorySummary objects.Method parameters in software.amazon.awssdk.services.codeartifact.model with type arguments of type RepositorySummaryModifier and TypeMethodDescriptionListRepositoriesInDomainResponse.Builder.repositories(Collection<RepositorySummary> repositories) The returned list of repositories.ListRepositoriesResponse.Builder.repositories(Collection<RepositorySummary> repositories) The returned list of RepositorySummary objects. -
Uses of RepositorySummary in software.amazon.awssdk.services.codeartifact.paginators
Methods in software.amazon.awssdk.services.codeartifact.paginators that return types with arguments of type RepositorySummaryModifier and TypeMethodDescriptionfinal SdkIterable<RepositorySummary>ListRepositoriesInDomainIterable.repositories()Returns an iterable to iterate through the paginatedListRepositoriesInDomainResponse.repositories()member.final SdkPublisher<RepositorySummary>ListRepositoriesInDomainPublisher.repositories()Returns a publisher that can be used to get a stream of data.final SdkIterable<RepositorySummary>ListRepositoriesIterable.repositories()Returns an iterable to iterate through the paginatedListRepositoriesResponse.repositories()member.final SdkPublisher<RepositorySummary>ListRepositoriesPublisher.repositories()Returns a publisher that can be used to get a stream of data.