Uses of Class
software.amazon.awssdk.services.codeartifact.model.UpstreamRepositoryInfo
Packages that use UpstreamRepositoryInfo
-
Uses of UpstreamRepositoryInfo in software.amazon.awssdk.services.codeartifact.model
Methods in software.amazon.awssdk.services.codeartifact.model that return types with arguments of type UpstreamRepositoryInfoModifier and TypeMethodDescriptionfinal List<UpstreamRepositoryInfo>RepositoryDescription.upstreams()A list of upstream repositories to associate with the repository.Methods in software.amazon.awssdk.services.codeartifact.model with parameters of type UpstreamRepositoryInfoModifier and TypeMethodDescriptionRepositoryDescription.Builder.upstreams(UpstreamRepositoryInfo... upstreams) A list of upstream repositories to associate with the repository.Method parameters in software.amazon.awssdk.services.codeartifact.model with type arguments of type UpstreamRepositoryInfoModifier and TypeMethodDescriptionRepositoryDescription.Builder.upstreams(Collection<UpstreamRepositoryInfo> upstreams) A list of upstream repositories to associate with the repository.