Class AssociateExternalConnectionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<AssociateExternalConnectionRequest.Builder,AssociateExternalConnectionRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringdomain()The name of the domain that contains the repository.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final StringThe name of the external connection to add to the repository.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe name of the repository to which the external connection is added.static Class<? extends AssociateExternalConnectionRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain that contains the repository.
- Returns:
- The name of the domain that contains the repository.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
repository
The name of the repository to which the external connection is added.
- Returns:
- The name of the repository to which the external connection is added.
-
externalConnection
The name of the external connection to add to the repository. The following values are supported:
-
public:npmjs- for the npm public repository. -
public:nuget-org- for the NuGet Gallery. -
public:pypi- for the Python Package Index. -
public:maven-central- for Maven Central. -
public:maven-googleandroid- for the Google Android repository. -
public:maven-gradleplugins- for the Gradle plugins repository. -
public:maven-commonsware- for the CommonsWare Android repository. -
public:maven-clojars- for the Clojars repository. -
public:ruby-gems-org- for RubyGems.org. -
public:crates-io- for Crates.io.
- Returns:
- The name of the external connection to add to the repository. The following values are supported:
-
public:npmjs- for the npm public repository. -
public:nuget-org- for the NuGet Gallery. -
public:pypi- for the Python Package Index. -
public:maven-central- for Maven Central. -
public:maven-googleandroid- for the Google Android repository. -
public:maven-gradleplugins- for the Gradle plugins repository. -
public:maven-commonsware- for the CommonsWare Android repository. -
public:maven-clojars- for the Clojars repository. -
public:ruby-gems-org- for RubyGems.org. -
public:crates-io- for Crates.io.
-
-
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AssociateExternalConnectionRequest.Builder,AssociateExternalConnectionRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
public static Class<? extends AssociateExternalConnectionRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-