Class DeletePackageVersionsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DeletePackageVersionsRequest.Builder,DeletePackageVersionsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringdomain()The name of the domain that contains the package to delete.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final PackageVersionStatusThe expected status of the package version to delete.final StringThe expected status of the package version to delete.final PackageFormatformat()The format of the package versions to delete.final StringThe format of the package versions to delete.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the Versions property.final StringThe namespace of the package versions to be deleted.final StringThe name of the package with the versions to delete.final StringThe name of the repository that contains the package versions to delete.static Class<? extends DeletePackageVersionsRequest.Builder>final StringtoString()Returns a string representation of this object.versions()An array of strings that specify the versions of the package to delete.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain that contains the package to delete.
- Returns:
- The name of the domain that contains the package to delete.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
repository
The name of the repository that contains the package versions to delete.
- Returns:
- The name of the repository that contains the package versions to delete.
-
format
The format of the package versions to delete.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- The format of the package versions to delete.
- See Also:
-
formatAsString
The format of the package versions to delete.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- The format of the package versions to delete.
- See Also:
-
namespace
The namespace of the package versions to be deleted. The package component that specifies its namespace depends on its type. For example:
The namespace is required when deleting package versions of the following formats:
-
Maven
-
Swift
-
generic
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
- Returns:
- The namespace of the package versions to be deleted. The package component that specifies its namespace
depends on its type. For example:
The namespace is required when deleting package versions of the following formats:
-
Maven
-
Swift
-
generic
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
-
-
-
packageValue
The name of the package with the versions to delete.
- Returns:
- The name of the package with the versions to delete.
-
hasVersions
public final boolean hasVersions()For responses, this returns true if the service returned a value for the Versions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
versions
An array of strings that specify the versions of the package to delete.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasVersions()method.- Returns:
- An array of strings that specify the versions of the package to delete.
-
expectedStatus
The expected status of the package version to delete.
If the service returns an enum value that is not available in the current SDK version,
expectedStatuswill returnPackageVersionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromexpectedStatusAsString().- Returns:
- The expected status of the package version to delete.
- See Also:
-
expectedStatusAsString
The expected status of the package version to delete.
If the service returns an enum value that is not available in the current SDK version,
expectedStatuswill returnPackageVersionStatus.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromexpectedStatusAsString().- Returns:
- The expected status of the package version to delete.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DeletePackageVersionsRequest.Builder,DeletePackageVersionsRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-