Class DeleteRepositoryPermissionsPolicyRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest
software.amazon.awssdk.services.codeartifact.model.DeleteRepositoryPermissionsPolicyRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DeleteRepositoryPermissionsPolicyRequest.Builder,DeleteRepositoryPermissionsPolicyRequest>
@Generated("software.amazon.awssdk:codegen")
public final class DeleteRepositoryPermissionsPolicyRequest
extends CodeartifactRequest
implements ToCopyableBuilder<DeleteRepositoryPermissionsPolicyRequest.Builder,DeleteRepositoryPermissionsPolicyRequest>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringdomain()The name of the domain that contains the repository associated with the resource policy to be deleted.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe revision of the repository's resource policy to be deleted.final StringThe name of the repository that is associated with the resource policy to be deletedstatic Class<? extends DeleteRepositoryPermissionsPolicyRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain that contains the repository associated with the resource policy to be deleted.
- Returns:
- The name of the domain that contains the repository associated with the resource policy to be deleted.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
repository
The name of the repository that is associated with the resource policy to be deleted
- Returns:
- The name of the repository that is associated with the resource policy to be deleted
-
policyRevision
The revision of the repository's resource policy to be deleted. This revision is used for optimistic locking, which prevents others from accidentally overwriting your changes to the repository's resource policy.
- Returns:
- The revision of the repository's resource policy to be deleted. This revision is used for optimistic locking, which prevents others from accidentally overwriting your changes to the repository's resource policy.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DeleteRepositoryPermissionsPolicyRequest.Builder,DeleteRepositoryPermissionsPolicyRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
public static Class<? extends DeleteRepositoryPermissionsPolicyRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-