Class DomainEntryPoint

  • All Implemented Interfaces:
    Serializable, SdkPojo, ToCopyableBuilder<DomainEntryPoint.Builder,​DomainEntryPoint>

    @Generated("software.amazon.awssdk:codegen")
    public final class DomainEntryPoint
    extends Object
    implements SdkPojo, Serializable, ToCopyableBuilder<DomainEntryPoint.Builder,​DomainEntryPoint>

    Information about how a package originally entered the CodeArtifact domain. For packages published directly to CodeArtifact, the entry point is the repository it was published to. For packages ingested from an external repository, the entry point is the external connection that it was ingested from. An external connection is a CodeArtifact repository that is connected to an external repository such as the npm registry or NuGet gallery.

    If a package version exists in a repository and is updated, for example if a package of the same version is added with additional assets, the package version's DomainEntryPoint will not change from the original package version's value.

    See Also:
    Serialized Form
    • Method Detail

      • repositoryName

        public final String repositoryName()

        The name of the repository that a package was originally published to.

        Returns:
        The name of the repository that a package was originally published to.
      • externalConnectionName

        public final String externalConnectionName()

        The name of the external connection that a package was ingested from.

        Returns:
        The name of the external connection that a package was ingested from.
      • hashCode

        public final int hashCode()
        Overrides:
        hashCode in class Object
      • equals

        public final boolean equals​(Object obj)
        Overrides:
        equals in class Object
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object
      • getValueForField

        public final <T> Optional<T> getValueForField​(String fieldName,
                                                      Class<T> clazz)