Class GetAuthorizationTokenRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest
software.amazon.awssdk.services.codeartifact.model.GetAuthorizationTokenRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetAuthorizationTokenRequest.Builder,GetAuthorizationTokenRequest>
@Generated("software.amazon.awssdk:codegen")
public final class GetAuthorizationTokenRequest
extends CodeartifactRequest
implements ToCopyableBuilder<GetAuthorizationTokenRequest.Builder,GetAuthorizationTokenRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringdomain()The name of the domain that is in scope for the generated authorization token.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final LongThe time, in seconds, that the generated authorization token is valid.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends GetAuthorizationTokenRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain that is in scope for the generated authorization token.
- Returns:
- The name of the domain that is in scope for the generated authorization token.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
durationSeconds
The time, in seconds, that the generated authorization token is valid. Valid values are
0and any number between900(15 minutes) and43200(12 hours). A value of0will set the expiration of the authorization token to the same expiration of the user's role's temporary credentials.- Returns:
- The time, in seconds, that the generated authorization token is valid. Valid values are
0and any number between900(15 minutes) and43200(12 hours). A value of0will set the expiration of the authorization token to the same expiration of the user's role's temporary credentials.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetAuthorizationTokenRequest.Builder,GetAuthorizationTokenRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-