Interface GetAuthorizationTokenRequest.Builder
- All Superinterfaces:
AwsRequest.Builder,Buildable,CodeartifactRequest.Builder,CopyableBuilder<GetAuthorizationTokenRequest.Builder,,GetAuthorizationTokenRequest> SdkBuilder<GetAuthorizationTokenRequest.Builder,,GetAuthorizationTokenRequest> SdkPojo,SdkRequest.Builder
- Enclosing class:
- GetAuthorizationTokenRequest
@Mutable
@NotThreadSafe
public static interface GetAuthorizationTokenRequest.Builder
extends CodeartifactRequest.Builder, SdkPojo, CopyableBuilder<GetAuthorizationTokenRequest.Builder,GetAuthorizationTokenRequest>
-
Method Summary
Modifier and TypeMethodDescriptionThe name of the domain that is in scope for the generated authorization token.domainOwner(String domainOwner) The 12-digit account number of the Amazon Web Services account that owns the domain.durationSeconds(Long durationSeconds) The time, in seconds, that the generated authorization token is valid.overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) Methods inherited from interface software.amazon.awssdk.awscore.AwsRequest.Builder
overrideConfigurationMethods inherited from interface software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest.Builder
buildMethods inherited from interface software.amazon.awssdk.utils.builder.CopyableBuilder
copyMethods inherited from interface software.amazon.awssdk.utils.builder.SdkBuilder
applyMutation, buildMethods inherited from interface software.amazon.awssdk.core.SdkPojo
equalsBySdkFields, sdkFieldNameToField, sdkFields
-
Method Details
-
domain
The name of the domain that is in scope for the generated authorization token.
- Parameters:
domain- The name of the domain that is in scope for the generated authorization token.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Parameters:
domainOwner- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
durationSeconds
The time, in seconds, that the generated authorization token is valid. Valid values are
0and any number between900(15 minutes) and43200(12 hours). A value of0will set the expiration of the authorization token to the same expiration of the user's role's temporary credentials.- Parameters:
durationSeconds- The time, in seconds, that the generated authorization token is valid. Valid values are0and any number between900(15 minutes) and43200(12 hours). A value of0will set the expiration of the authorization token to the same expiration of the user's role's temporary credentials.- Returns:
- Returns a reference to this object so that method calls can be chained together.
-
overrideConfiguration
GetAuthorizationTokenRequest.Builder overrideConfiguration(AwsRequestOverrideConfiguration overrideConfiguration) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-
overrideConfiguration
GetAuthorizationTokenRequest.Builder overrideConfiguration(Consumer<AwsRequestOverrideConfiguration.Builder> builderConsumer) - Specified by:
overrideConfigurationin interfaceAwsRequest.Builder
-