Class GetPackageVersionReadmeResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<GetPackageVersionReadmeResponse.Builder,GetPackageVersionReadmeResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final PackageFormatformat()The format of the package with the requested readme file.final StringThe format of the package with the requested readme file.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe namespace of the package version with the requested readme file.final StringThe name of the package that contains the returned readme file.final Stringreadme()The text of the returned readme file.static Class<? extends GetPackageVersionReadmeResponse.Builder>final StringtoString()Returns a string representation of this object.final Stringversion()The version of the package with the requested readme file.final StringThe current revision associated with the package version.Methods inherited from class software.amazon.awssdk.services.codeartifact.model.CodeartifactResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
format
The format of the package with the requested readme file.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- The format of the package with the requested readme file.
- See Also:
-
formatAsString
The format of the package with the requested readme file.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- The format of the package with the requested readme file.
- See Also:
-
namespace
The namespace of the package version with the requested readme file. The package component that specifies its namespace depends on its type. For example:
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
- Returns:
- The namespace of the package version with the requested readme file. The package component that specifies
its namespace depends on its type. For example:
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
-
-
-
packageValue
The name of the package that contains the returned readme file.
- Returns:
- The name of the package that contains the returned readme file.
-
version
The version of the package with the requested readme file.
- Returns:
- The version of the package with the requested readme file.
-
versionRevision
The current revision associated with the package version.
- Returns:
- The current revision associated with the package version.
-
readme
The text of the returned readme file.
- Returns:
- The text of the returned readme file.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<GetPackageVersionReadmeResponse.Builder,GetPackageVersionReadmeResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-