Class GetRepositoryEndpointRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<GetRepositoryEndpointRequest.Builder,GetRepositoryEndpointRequest>

@Generated("software.amazon.awssdk:codegen") public final class GetRepositoryEndpointRequest extends CodeartifactRequest implements ToCopyableBuilder<GetRepositoryEndpointRequest.Builder,GetRepositoryEndpointRequest>
  • Method Details

    • domain

      public final String domain()

      The name of the domain that contains the repository.

      Returns:
      The name of the domain that contains the repository.
    • domainOwner

      public final String domainOwner()

      The 12-digit account number of the Amazon Web Services account that owns the domain that contains the repository. It does not include dashes or spaces.

      Returns:
      The 12-digit account number of the Amazon Web Services account that owns the domain that contains the repository. It does not include dashes or spaces.
    • repository

      public final String repository()

      The name of the repository.

      Returns:
      The name of the repository.
    • format

      public final PackageFormat format()

      Returns which endpoint of a repository to return. A repository has one endpoint for each package format.

      If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

      Returns:
      Returns which endpoint of a repository to return. A repository has one endpoint for each package format.
      See Also:
    • formatAsString

      public final String formatAsString()

      Returns which endpoint of a repository to return. A repository has one endpoint for each package format.

      If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

      Returns:
      Returns which endpoint of a repository to return. A repository has one endpoint for each package format.
      See Also:
    • endpointType

      public final EndpointType endpointType()

      A string that specifies the type of endpoint.

      If the service returns an enum value that is not available in the current SDK version, endpointType will return EndpointType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from endpointTypeAsString().

      Returns:
      A string that specifies the type of endpoint.
      See Also:
    • endpointTypeAsString

      public final String endpointTypeAsString()

      A string that specifies the type of endpoint.

      If the service returns an enum value that is not available in the current SDK version, endpointType will return EndpointType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from endpointTypeAsString().

      Returns:
      A string that specifies the type of endpoint.
      See Also:
    • toBuilder

      Specified by:
      toBuilder in interface ToCopyableBuilder<GetRepositoryEndpointRequest.Builder,GetRepositoryEndpointRequest>
      Specified by:
      toBuilder in class CodeartifactRequest
    • builder

      public static GetRepositoryEndpointRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends GetRepositoryEndpointRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo