Class GetRepositoryEndpointRequest

    • Method Detail

      • domain

        public final String domain()

        The name of the domain that contains the repository.

        Returns:
        The name of the domain that contains the repository.
      • domainOwner

        public final String domainOwner()

        The 12-digit account number of the Amazon Web Services account that owns the domain that contains the repository. It does not include dashes or spaces.

        Returns:
        The 12-digit account number of the Amazon Web Services account that owns the domain that contains the repository. It does not include dashes or spaces.
      • repository

        public final String repository()

        The name of the repository.

        Returns:
        The name of the repository.
      • format

        public final PackageFormat format()

        Returns which endpoint of a repository to return. A repository has one endpoint for each package format.

        If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

        Returns:
        Returns which endpoint of a repository to return. A repository has one endpoint for each package format.
        See Also:
        PackageFormat
      • formatAsString

        public final String formatAsString()

        Returns which endpoint of a repository to return. A repository has one endpoint for each package format.

        If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

        Returns:
        Returns which endpoint of a repository to return. A repository has one endpoint for each package format.
        See Also:
        PackageFormat
      • endpointType

        public final EndpointType endpointType()

        A string that specifies the type of endpoint.

        If the service returns an enum value that is not available in the current SDK version, endpointType will return EndpointType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from endpointTypeAsString().

        Returns:
        A string that specifies the type of endpoint.
        See Also:
        EndpointType
      • endpointTypeAsString

        public final String endpointTypeAsString()

        A string that specifies the type of endpoint.

        If the service returns an enum value that is not available in the current SDK version, endpointType will return EndpointType.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from endpointTypeAsString().

        Returns:
        A string that specifies the type of endpoint.
        See Also:
        EndpointType
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object