Class ListPackageGroupsRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest
software.amazon.awssdk.services.codeartifact.model.ListPackageGroupsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListPackageGroupsRequest.Builder,ListPackageGroupsRequest>
@Generated("software.amazon.awssdk:codegen")
public final class ListPackageGroupsRequest
extends CodeartifactRequest
implements ToCopyableBuilder<ListPackageGroupsRequest.Builder,ListPackageGroupsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringdomain()The domain for which you want to list package groups.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe maximum number of results to return per page.final StringThe token for the next set of results.final Stringprefix()A prefix for which to search package groups.static Class<? extends ListPackageGroupsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The domain for which you want to list package groups.
- Returns:
- The domain for which you want to list package groups.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
maxResults
The maximum number of results to return per page.
- Returns:
- The maximum number of results to return per page.
-
nextToken
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
- Returns:
- The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
-
prefix
A prefix for which to search package groups. When included,
ListPackageGroupswill return only package groups with patterns that match the prefix.- Returns:
- A prefix for which to search package groups. When included,
ListPackageGroupswill return only package groups with patterns that match the prefix.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListPackageGroupsRequest.Builder,ListPackageGroupsRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-