Class ListPackageVersionAssetsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListPackageVersionAssetsRequest.Builder,ListPackageVersionAssetsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringdomain()The name of the domain that contains the repository associated with the package version assets.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final PackageFormatformat()The format of the package that contains the requested package version assets.final StringThe format of the package that contains the requested package version assets.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe maximum number of results to return per page.final StringThe namespace of the package version that contains the requested package version assets.final StringThe token for the next set of results.final StringThe name of the package that contains the requested package version assets.final StringA string that contains the package version (for example,3.5.2).final StringThe name of the repository that contains the package that contains the requested package version assets.static Class<? extends ListPackageVersionAssetsRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain that contains the repository associated with the package version assets.
- Returns:
- The name of the domain that contains the repository associated with the package version assets.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
repository
The name of the repository that contains the package that contains the requested package version assets.
- Returns:
- The name of the repository that contains the package that contains the requested package version assets.
-
format
The format of the package that contains the requested package version assets.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- The format of the package that contains the requested package version assets.
- See Also:
-
formatAsString
The format of the package that contains the requested package version assets.
If the service returns an enum value that is not available in the current SDK version,
formatwill returnPackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromformatAsString().- Returns:
- The format of the package that contains the requested package version assets.
- See Also:
-
namespace
The namespace of the package version that contains the requested package version assets. The package component that specifies its namespace depends on its type. For example:
The namespace is required requesting assets from package versions of the following formats:
-
Maven
-
Swift
-
generic
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
- Returns:
- The namespace of the package version that contains the requested package version assets. The package
component that specifies its namespace depends on its type. For example:
The namespace is required requesting assets from package versions of the following formats:
-
Maven
-
Swift
-
generic
-
The namespace of a Maven package version is its
groupId. -
The namespace of an npm or Swift package version is its
scope. -
The namespace of a generic package is its
namespace. -
Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.
-
-
-
packageValue
The name of the package that contains the requested package version assets.
- Returns:
- The name of the package that contains the requested package version assets.
-
packageVersion
A string that contains the package version (for example,
3.5.2).- Returns:
- A string that contains the package version (for example,
3.5.2).
-
maxResults
The maximum number of results to return per page.
- Returns:
- The maximum number of results to return per page.
-
nextToken
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
- Returns:
- The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListPackageVersionAssetsRequest.Builder,ListPackageVersionAssetsRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-