Class ListRepositoriesInDomainRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest
software.amazon.awssdk.services.codeartifact.model.ListRepositoriesInDomainRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ListRepositoriesInDomainRequest.Builder,ListRepositoriesInDomainRequest>
@Generated("software.amazon.awssdk:codegen")
public final class ListRepositoriesInDomainRequest
extends CodeartifactRequest
implements ToCopyableBuilder<ListRepositoriesInDomainRequest.Builder,ListRepositoriesInDomainRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringFilter the list of repositories to only include those that are managed by the Amazon Web Services account ID.builder()final Stringdomain()The name of the domain that contains the returned list of repositories.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final IntegerThe maximum number of results to return per page.final StringThe token for the next set of results.final StringA prefix used to filter returned repositories.static Class<? extends ListRepositoriesInDomainRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain that contains the returned list of repositories.
- Returns:
- The name of the domain that contains the returned list of repositories.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
administratorAccount
Filter the list of repositories to only include those that are managed by the Amazon Web Services account ID.
- Returns:
- Filter the list of repositories to only include those that are managed by the Amazon Web Services account ID.
-
repositoryPrefix
A prefix used to filter returned repositories. Only repositories with names that start with
repositoryPrefixare returned.- Returns:
- A prefix used to filter returned repositories. Only repositories with names that start with
repositoryPrefixare returned.
-
maxResults
The maximum number of results to return per page.
- Returns:
- The maximum number of results to return per page.
-
nextToken
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
- Returns:
- The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ListRepositoriesInDomainRequest.Builder,ListRepositoriesInDomainRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-