Class PackageDescription

java.lang.Object
software.amazon.awssdk.services.codeartifact.model.PackageDescription
All Implemented Interfaces:
Serializable, SdkPojo, ToCopyableBuilder<PackageDescription.Builder,PackageDescription>

@Generated("software.amazon.awssdk:codegen") public final class PackageDescription extends Object implements SdkPojo, Serializable, ToCopyableBuilder<PackageDescription.Builder,PackageDescription>

Details about a package.

See Also:
  • Method Details

    • format

      public final PackageFormat format()

      A format that specifies the type of the package.

      If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

      Returns:
      A format that specifies the type of the package.
      See Also:
    • formatAsString

      public final String formatAsString()

      A format that specifies the type of the package.

      If the service returns an enum value that is not available in the current SDK version, format will return PackageFormat.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available from formatAsString().

      Returns:
      A format that specifies the type of the package.
      See Also:
    • namespace

      public final String namespace()

      The namespace of the package. The package component that specifies its namespace depends on its type. For example:

      • The namespace of a Maven package version is its groupId.

      • The namespace of an npm or Swift package version is its scope.

      • The namespace of a generic package is its namespace.

      • Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.

      Returns:
      The namespace of the package. The package component that specifies its namespace depends on its type. For example:

      • The namespace of a Maven package version is its groupId.

      • The namespace of an npm or Swift package version is its scope.

      • The namespace of a generic package is its namespace.

      • Python, NuGet, Ruby, and Cargo package versions do not contain a corresponding component, package versions of those formats do not have a namespace.

    • name

      public final String name()

      The name of the package.

      Returns:
      The name of the package.
    • originConfiguration

      public final PackageOriginConfiguration originConfiguration()

      The package origin configuration for the package.

      Returns:
      The package origin configuration for the package.
    • toBuilder

      public PackageDescription.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<PackageDescription.Builder,PackageDescription>
    • builder

      public static PackageDescription.Builder builder()
    • serializableBuilderClass

      public static Class<? extends PackageDescription.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class Object
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class Object
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo