Class PutRepositoryPermissionsPolicyRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest
software.amazon.awssdk.services.codeartifact.model.PutRepositoryPermissionsPolicyRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PutRepositoryPermissionsPolicyRequest.Builder,PutRepositoryPermissionsPolicyRequest>
@Generated("software.amazon.awssdk:codegen")
public final class PutRepositoryPermissionsPolicyRequest
extends CodeartifactRequest
implements ToCopyableBuilder<PutRepositoryPermissionsPolicyRequest.Builder,PutRepositoryPermissionsPolicyRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Stringdomain()The name of the domain containing the repository to set the resource policy on.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringA valid displayable JSON Aspen policy string to be set as the access control resource policy on the provided repository.final StringSets the revision of the resource policy that specifies permissions to access the repository.final StringThe name of the repository to set the resource policy on.static Class<? extends PutRepositoryPermissionsPolicyRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain containing the repository to set the resource policy on.
- Returns:
- The name of the domain containing the repository to set the resource policy on.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
repository
The name of the repository to set the resource policy on.
- Returns:
- The name of the repository to set the resource policy on.
-
policyRevision
Sets the revision of the resource policy that specifies permissions to access the repository. This revision is used for optimistic locking, which prevents others from overwriting your changes to the repository's resource policy.
- Returns:
- Sets the revision of the resource policy that specifies permissions to access the repository. This revision is used for optimistic locking, which prevents others from overwriting your changes to the repository's resource policy.
-
policyDocument
A valid displayable JSON Aspen policy string to be set as the access control resource policy on the provided repository.
- Returns:
- A valid displayable JSON Aspen policy string to be set as the access control resource policy on the provided repository.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PutRepositoryPermissionsPolicyRequest.Builder,PutRepositoryPermissionsPolicyRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
public static Class<? extends PutRepositoryPermissionsPolicyRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-