Class UpdatePackageGroupOriginConfigurationRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdatePackageGroupOriginConfigurationRequest.Builder,UpdatePackageGroupOriginConfigurationRequest>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionThe repository name and restrictions to add to the allowed repository list of the specified package group.builder()final Stringdomain()The name of the domain which contains the package group for which to update the origin configuration.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the AddAllowedRepositories property.final inthashCode()final booleanFor responses, this returns true if the service returned a value for the RemoveAllowedRepositories property.final booleanFor responses, this returns true if the service returned a value for the Restrictions property.final StringThe pattern of the package group for which to update the origin configuration.The repository name and restrictions to remove from the allowed repository list of the specified package group.The origin configuration settings that determine how package versions can enter repositories.The origin configuration settings that determine how package versions can enter repositories.static Class<? extends UpdatePackageGroupOriginConfigurationRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain which contains the package group for which to update the origin configuration.
- Returns:
- The name of the domain which contains the package group for which to update the origin configuration.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
packageGroup
The pattern of the package group for which to update the origin configuration.
- Returns:
- The pattern of the package group for which to update the origin configuration.
-
restrictions
public final Map<PackageGroupOriginRestrictionType,PackageGroupOriginRestrictionMode> restrictions()The origin configuration settings that determine how package versions can enter repositories.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasRestrictions()method.- Returns:
- The origin configuration settings that determine how package versions can enter repositories.
-
hasRestrictions
public final boolean hasRestrictions()For responses, this returns true if the service returned a value for the Restrictions property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
restrictionsAsStrings
The origin configuration settings that determine how package versions can enter repositories.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasRestrictions()method.- Returns:
- The origin configuration settings that determine how package versions can enter repositories.
-
hasAddAllowedRepositories
public final boolean hasAddAllowedRepositories()For responses, this returns true if the service returned a value for the AddAllowedRepositories property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
addAllowedRepositories
The repository name and restrictions to add to the allowed repository list of the specified package group.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasAddAllowedRepositories()method.- Returns:
- The repository name and restrictions to add to the allowed repository list of the specified package group.
-
hasRemoveAllowedRepositories
public final boolean hasRemoveAllowedRepositories()For responses, this returns true if the service returned a value for the RemoveAllowedRepositories property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
removeAllowedRepositories
The repository name and restrictions to remove from the allowed repository list of the specified package group.
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasRemoveAllowedRepositories()method.- Returns:
- The repository name and restrictions to remove from the allowed repository list of the specified package group.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdatePackageGroupOriginConfigurationRequest.Builder,UpdatePackageGroupOriginConfigurationRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
public static Class<? extends UpdatePackageGroupOriginConfigurationRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-