Class UpdatePackageGroupOriginConfigurationResponse

    • Method Detail

      • packageGroup

        public final PackageGroupDescription packageGroup()

        The package group and information about it after processing the request.

        Returns:
        The package group and information about it after processing the request.
      • allowedRepositoryUpdates

        public final Map<PackageGroupOriginRestrictionType,​Map<PackageGroupAllowedRepositoryUpdateType,​List<String>>> allowedRepositoryUpdates()

        Information about the updated allowed repositories after processing the request.

        Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

        This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasAllowedRepositoryUpdates() method.

        Returns:
        Information about the updated allowed repositories after processing the request.
      • hasAllowedRepositoryUpdates

        public final boolean hasAllowedRepositoryUpdates()
        For responses, this returns true if the service returned a value for the AllowedRepositoryUpdates property. This DOES NOT check that the value is non-empty (for which, you should check the isEmpty() method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified.
      • allowedRepositoryUpdatesAsStrings

        public final Map<String,​Map<String,​List<String>>> allowedRepositoryUpdatesAsStrings()

        Information about the updated allowed repositories after processing the request.

        Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.

        This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the hasAllowedRepositoryUpdates() method.

        Returns:
        Information about the updated allowed repositories after processing the request.
      • toString

        public final String toString()
        Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
        Overrides:
        toString in class Object