Class UpdatePackageGroupRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.codeartifact.model.CodeartifactRequest
software.amazon.awssdk.services.codeartifact.model.UpdatePackageGroupRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdatePackageGroupRequest.Builder,UpdatePackageGroupRequest>
@Generated("software.amazon.awssdk:codegen")
public final class UpdatePackageGroupRequest
extends CodeartifactRequest
implements ToCopyableBuilder<UpdatePackageGroupRequest.Builder,UpdatePackageGroupRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringContact information which you want to update the requested package group with.final StringThe description you want to update the requested package group with.final Stringdomain()The name of the domain which contains the package group to be updated.final StringThe 12-digit account number of the Amazon Web Services account that owns the domain.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe pattern of the package group to be updated.static Class<? extends UpdatePackageGroupRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
domain
The name of the domain which contains the package group to be updated.
- Returns:
- The name of the domain which contains the package group to be updated.
-
domainOwner
The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
- Returns:
- The 12-digit account number of the Amazon Web Services account that owns the domain. It does not include dashes or spaces.
-
packageGroup
The pattern of the package group to be updated.
- Returns:
- The pattern of the package group to be updated.
-
contactInfo
Contact information which you want to update the requested package group with.
- Returns:
- Contact information which you want to update the requested package group with.
-
description
The description you want to update the requested package group with.
- Returns:
- The description you want to update the requested package group with.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdatePackageGroupRequest.Builder,UpdatePackageGroupRequest> - Specified by:
toBuilderin classCodeartifactRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-